<?php

// Represents the adjustment values for an AutoShapes.
class Adjustments {

	public $m_adjustments;

	function __construct($adjustments) {
		$this->m_adjustments = $adjustments;
	}

	// Returns the element at the specified index
	function get($index) {
		$int = $this->m_adjustments->get($index);
		return $int;
	}

	// Returns the number of elements actually contained in the collection.
	function size() {
		$int = $this->m_adjustments->size();
		return $int;
	}
}

// Represents an animation effects you can apply to the specified shape.
class AnimationSettings {

	public $m_animationSettings;

	function __construct($as) {
		$this->m_animationSettings = $as;
	}

	// Returns the value that indicates whether the specified shape animation advances only when clicked or automatically after a specified amount of time.
	function getAdvanceMode() {
		$int = $this->m_animationSettings->getAdvanceMode();
		return $int;
	}

	// Returns the amount of time, in seconds, after which the specified shape animation will occur.
	function getAdvanceTime() {
		$double = $this->m_animationSettings->getAdvanceTime();
		return $double;
	}

	// Determines whether the specified slide advances automatically after a specified amount of time has elapsed.
	function getAfterEffect() {
		$int = $this->m_animationSettings->getAfterEffect();
		return $int;
	}

	// Returns the integer that represents the position of the specified shape within the collection of shapes to be animated.
	function getAnimationOrder() {
		$int = $this->m_animationSettings->getAnimationOrder();
		return $int;
	}

	// Returns the number of slides where shape will be animated.
	function getAnimationSlideCount() {
		$int = $this->m_animationSettings->getAnimationSlideCount();
		return $int;
	}

	// Returns the special effect applied to the specified shape animation.
	function getEntryEffect() {
		$int = $this->m_animationSettings->getEntryEffect();
		return $int;
	}

	// Returns the constant that indicates whether the text in the specified shape is animated by first-level paragraphs, second-level paragraphs, or some other level (up to fifth-level paragraphs).
	function getTextLevelEffect() {
		$int = $this->m_animationSettings->getTextLevelEffect();
		return $int;
	}

	// Returns the constant that indicates whether the text in the specified shape is animated paragraph by paragraph, word by word, or letter by letter.
	function getTextUnitEffect() {
		$int = $this->m_animationSettings->getTextUnitEffect();
		return $int;
	}

	// Determines whether the shape is animated together with the text it contains.
	function isAnimateBackground() {
		$boolean = $this->m_animationSettings->isAnimateBackground();
		return $boolean;
	}

	// Determines whether the specified shape is animated in reverse order.
	function isAnimateTextInReverse() {
		$boolean = $this->m_animationSettings->isAnimateTextInReverse();
		return $boolean;
	}

	// Sets the value that indicates whether the specified shape animation advances only when clicked or automatically after a specified amount of time.
	function setAdvanceMode($int) {
		$this->m_animationSettings->setAdvanceMode($int);
	}

	// Sets the amount of time, in seconds, after which the specified shape animation will occur.
	function setAdvanceTime($double) {
		$this->m_animationSettings->setAdvanceTime($double);
	}

	// Sets whether the specified slide advances automatically after a specified amount of time has elapsed.
	function setAfterEffect($int) {
		$this->m_animationSettings->setAfterEffect($int);
	}

	// Sets whether the shape is animated together with the text it contains.
	function setAnimateBackground($boolean) {
		$this->m_animationSettings->setAnimateBackground($boolean);
	}

	// Sets whether the specified shape is animated in reverse order.
	function setAnimateTextInReverse($boolean) {
		$this->m_animationSettings->setAnimateTextInReverse($boolean);
	}

	// Sets the integer that represents the position of the specified shape within the collection of shapes to be animated.
	function setAnimationOrder($int) {
		$this->m_animationSettings->setAnimationOrder($int);
	}

	// Sets the number of slides where shape will be animated.
	function setAnimationSlideCount($int) {
		$this->m_animationSettings->setAnimationSlideCount($int);
	}

	// Sets the special effect applied to the specified shape animation.
	function setEntryEffect($int) {
		$this->m_animationSettings->setEntryEffect($int);
	}

	// Sets the constant that indicates whether the text in the specified shape is animated by first-level paragraphs, second-level paragraphs, or some other level (up to fifth-level paragraphs).
	function setTextLevelEffect($int) {
		$this->m_animationSettings->setTextLevelEffect($int);
	}

	// Sets the constant that indicates whether the text in the specified shape is animated paragraph by paragraph, word by word, or letter by letter.
	function setTextUnitEffect($int) {
		$this->m_animationSettings->setTextUnitEffect($int);
	}
}

// Represents an AudioFrame shape.
class AudioFrame extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns embedded audio data.
	function getAudioData() {
		$byte_array = $this->m_shape->getAudioData();
		return $byte_array;
	}

	// Returns the file from which the media object was created.
	function getFileName() {
		$string = $this->m_shape->getFileName();
		return $string;
	}

	// Determines whether the sound is embedded to a presentation.
	function isEmbedded() {
		$boolean = $this->m_shape->isEmbedded();
		return $boolean;
	}

	// Determines whether the sound loops continuously until either the next movie or sound starts, the user clicks the slide, or a slide transition occurs.
	function isLoopUntilStopped() {
		$boolean = $this->m_shape->isLoopUntilStopped();
		return $boolean;
	}

	// Determines whether the sound is automatically rewinded to start as soon as the sound has finished playing.
	function isRewindSound() {
		$boolean = $this->m_shape->isRewindSound();
		return $boolean;
	}

	// Sets the file from which the media object was created.
	function setFileName($string) {
		$this->m_shape->setFileName($string);
	}

	// Sets whether the sound loops continuously until either the next movie or sound starts, the user clicks the slide, or a slide transition occurs.
	function setLoopUntilStopped($boolean) {
		$this->m_shape->setLoopUntilStopped($boolean);
	}

	// Sets whether the sound is automatically rewinded to start as soon as the sound has finished playing.
	function setRewindSound($boolean) {
		$this->m_shape->setRewindSound($boolean);
	}

	// Returns the brightness (0-100%) of a picture.
	function getBrightness() {
		$int = $this->m_shape->getBrightness();
		return $int;
	}

	// Returns the type of color transformation applied to a picture.
	function getColorType() {
		$int = $this->m_shape->getColorType();
		return $int;
	}

	// Returns the contrast (0-100%) of a picture.
	function getContrast() {
		$int = $this->m_shape->getContrast();
		return $int;
	}

	// Returns the number of percents of real image height that are cropped off the bottom of the picture.
	function getCropBottom() {
		$double = $this->m_shape->getCropBottom();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the left of the picture.
	function getCropLeft() {
		$double = $this->m_shape->getCropLeft();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the right of the picture.
	function getCropRight() {
		$double = $this->m_shape->getCropRight();
		return $double;
	}

	// Returns the number of percents of real image height that are cropped off the top of the picture.
	function getCropTop() {
		$double = $this->m_shape->getCropTop();
		return $double;
	}

	// Returns the picture Id for a PictureFrame.
	function getPictureId() {
		$int = $this->m_shape->getPictureId();
		return $int;
	}

	// Returns the table of colors replacements for recoloring metafiles.
	function getRecolor() {
		$recolorTable = $this->m_shape->getRecolor();
		$recolorTable_php = new RecolorTable($recolorTable);
		return $recolorTable_php;
	}

	// Returns the transparent color of a picture.
	// java.awt.Color
	function getTransparentColor() {
		$color = $this->m_shape->getTransparentColor();
		return $color;
	}

	// Sets the brightness (0-100%) of a picture.
	function setBrightness($int) {
		$this->m_shape->setBrightness($int);
	}

	// Sets the type of color transformation applied to a picture.
	function setColorType($int) {
		$this->m_shape->setColorType($int);
	}

	// Sets the contrast (0-100%) of a picture.
	function setContrast($int) {
		$this->m_shape->setContrast($int);
	}

	// Sets the number of percents of real image height that are cropped off the bottom of the picture.
	function setCropBottom($double) {
		$this->m_shape->setCropBottom($double);
	}

	// Sets the number of percents of real image width that are cropped off the left of the picture.
	function setCropLeft($double) {
		$this->m_shape->setCropLeft($double);
	}

	// Sets the number of percents of real image width that are cropped off the right of the picture.
	function setCropRight($double) {
		$this->m_shape->setCropRight($double);
	}

	// Sets the number of percents of real image height that are cropped off the top of the picture.
	function setCropTop($double) {
		$this->m_shape->setCropTop($double);
	}

	// Sets the picture Id for a PictureFrame.
	function setPictureId($int) {
		$this->m_shape->setPictureId($int);
	}

	// sets the transparent color of a picture.
	function setTransparentColor($Color) {
		$this->m_shape->setTransparentColor($Color);
	}
}

// Represents the AutoShape shape.
class AutoShape extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns adjustments values for the AutoShape.
	function getAdjustments() {
		$adjustments = $this->m_shape->getAdjustments();
		$adjustments_php = new Adjustments($adjustments);
		return $adjustments_php;
	}

	// Returns type of an AutoShape.
	function getShapeType() {
		$int = $this->m_shape->getShapeType();
		return $int;
	}
}

// Represents the background of a slide.
class Background extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}
}

// Represents the cell of a table.
class Cell {

	public $m_cell;

	function __construct($cell) {
		$m_cell = $cell;
	}

	// Returns the bottom border of a cell.
	function getBorderBottom() {
		$border = $this->m_cell->getBorderBottom();
		$border_php = new CellBorder($border);
		return $border_php;
	}

	// Returns the left border of a cell.
	function getBorderLeft() {
		$border = $this->m_cell->getBorderLeft();
		$border_php = new CellBorder($border);
		return $border_php;
	}

	// Returns the right border of a cell.
	function getBorderRight() {
		$border = $this->m_cell->getBorderRight();
		$border_php = new CellBorder($border);
		return $border_php;
	}

	// Returns the top border of a cell.
	function getBorderTop() {
		$border = $this->m_cell->getBorderTop();
		$border_php = new CellBorder($border);
		return $border_php;
	}

	// Returns the FillFormat object that contains fill formatting properties for a cell.
	function getFillFormat() {
		$fillFormat = $this->m_cell->getFillFormat();
		$fillFormat_php = new FillFormat($fillFormat);
		return $fillFormat_php;
	}

	// Returns the height of a cell.
	function getHeight() {
		$int = $this->m_cell->getHeight();
		return $int;
	}

	// Returns the parent Table object for a cell.
	function getTable() {
		$table = $this->m_cell->getTable();
		$table_php = new Table($table);
		return $table_php;
	}

	// Returns the TextFrame object for a cell.
	function getTextFrame() {
		$textFrame = $this->m_cell->getTextFrame();
		$textFrame_php = new TextFrame($textFrame);
		return $textFrame_php;
	}

	// Returns the width of a cell.
	function getWidth() {
		$int = $this->m_cell->getWidth();
		return $int;
	}
}

// Represents the border of a cell.
class CellBorder {

	public $m_cellBorder;

	function __construct($border) {
		$this->m_cellBorder = $border;
	}

	// Returns the LineFormat object that contains line formatting properties for a cell border.
	function getLineFormat() {
		$lineFormat = $this->m_cellBorder->getLineFormat();
		$lineFormat_php = new LineFormat($lineFormat);
		return $lineFormat_php;
	}
}

class ClassFactory {

	function __construct() {
	}

	// Initializes a new instance of the FontEntity class.
	static function NewFontEntity($pres, $fontEntity) {
		$font = new Java('com.aspose.slides.FontEntity', $pres->m_presentation, $fontEntity->m_fontEntity);
		$font_php = new FontEntity($font);
		return $font_php;
	}

	// Initializes a new instance of this class.
	static function NewLicense() {
		$license = new Java('com.aspose.slides.License');
		$license_php = new License($license);
		return $license_php;
	}

	// Initializes a new instance of the Paragraph class.
	static function NewParagraph() {
		$para = new Java('com.aspose.slides.Paragraph');
		$para_php = new Paragraph($para);
		return $para_php;
	}

	// Initializes a new instance of the Paragraph class.
	static function CloneParagraph($paragraph) {
		$para = new Java('com.aspose.slides.Paragraph', $paragraph->m_paragraph);
		$para_php = new Paragraph($para);
		return $para_php;
	}

	// This constructor gets a source stream from which the contents of the Picture are read.
	static function NewPicture($parentPres, $input) {
		$picture = null;
		if (is_string($input)) {
			$input_file = new Java('java.io.File', $input);
			$input_stream = new Java('java.io.FileInputStream', $input_file);
			$picture = new Java('com.aspose.slides.Picture', $parentPres->m_presentation, $input_stream);
			$input_stream->close();
		} else {
			$picture = new Java('com.aspose.slides.Picture', $parentPres->m_presentation, $input);
		}
		$picture_php = new Picture($picture);
		return $picture_php;
	}

	// This constructor gets another picture as a source.
	static function ClonePicture($parentPres, $ppImage) {
		$picture = new Java('com.aspose.slides.Picture', $parentPres->m_presentation, $ppImage->m_image);
		$picture_php = new Picture($picture);
		return $picture_php;
	}

	// This constructor gets a source stream from which the contents of the Picture are read.
	static function NewPictureBullet($parentPres, $input) {
		$picture = null;
		if (is_string($input)) {
			$input_file = new Java('java.io.File', $input);
			$input_stream = new Java('java.io.FileInputStream', $input_file);
			$picture = new Java('com.aspose.slides.PictureBullet', $parentPres->m_presentation, $input_stream);
			$input_stream->close();
		} else {
			$picture = new Java('com.aspose.slides.PictureBullet', $parentPres->m_presentation, $input);
		}
		$picture_php = new PictureBullet($picture);
		return $picture_php;
	}

	// This constructor gets another picture as a source.
	static function ClonePictureBullet($parentPres, $ppImage) {
		$picture = new Java('com.aspose.slides.PictureBullet', $parentPres->m_presentation, $ppImage->m_image);
		$picture_php = new PictureBullet($picture);
		return $picture_php;
	}

	// Initializes a new instance of the Portion class.
	static function NewPortion() {
		$portion = new Java('com.aspose.slides.Portion');
		$portion_php = new Portion($portion);
		return $portion_php;
	}

	// Initializes a new instance of the Portion class.
	static function ClonePortion($port) {
		$portion = new Java('com.aspose.slides.Portion', $port->m_portion);
		$portion_php = new Portion($portion);
		return $portion_php;
	}

	// Initializes a new instance of the Portion class.
	static function PortionFromString($string) {
		$portion = new Java('com.aspose.slides.Portion', $string);
		$portion_php = new Portion($portion);
		return $portion_php;
	}

	// This function is the primary mechanism for reading an existing Presentation.
	static function NewPresentation($input) {
		$pres = null;
		if (is_string($input)) {
			$input_file = new Java('java.io.File', $input);
			$input_stream = new Java('java.io.FileInputStream', $input_file);
			$pres = new Java('com.aspose.slides.Presentation', $input_stream);
			$input_stream->close();
		} else {
			$pres = new Java('com.aspose.slides.Presentation', $input);
		}
		$pres_php = new Presentation($pres);
		return $pres_php;
	}

	// Initializes a new instance of the Tab class.
	static function NewTab($intPosition, $intAlign) {
		$tab = new Java('com.aspose.slides.Tab', $intPosition, $intAlign);
		$tab_php = new Tab($tab);
		return $tab_php;
	}

	static function CreateSlidePhp($slide) {
		if ($slide instanceof Java) {
			$type = "" . $slide->getClass();
			if ($type == "class com.aspose.slides.Slide") {
				$slide_php = new Slide($slide);
				return $slide_php;
			}
			if ($type == "class com.aspose.slides.MainMaster") {
				$slide_php = new MainMaster($slide);
				return $slide_php;
			}
		}
		return null;
	}

	static function CreatePlaceholderPhp($holder) {
		if ($holder instanceof Java) {
			$type = "" . $holder->getClass();
			if ($type == "class com.aspose.slides.Placeholder") {
				$holder_php = new Placeholder($holder);
				return $holder_php;
			}
			if ($type == "class com.aspose.slides.TextHolder") {
				$holder_php = new TextHolder($holder);
				return $holder_php;
			}
		}
		return null;
	}

	static function CreateShapesParentPhp($parent) {
		if ($parent instanceof Java) {
			$type = "" . $parent->getClass();
			if ($type == "class com.aspose.slides.Slide") {
				$parent_php = new Slide($parent);
				return $parent_php;
			}
			if ($type == "class com.aspose.slides.MainMaster") {
				$parent_php = new MainMaster($parent);
				return $parent_php;
			}
			if ($type == "class com.aspose.slides.GroupShape") {
				$parent_php = new GroupShape($parent);
				return $parent_php;
			}
			if ($type == "class com.aspose.slides.Table") {
				$parent_php = new Table($parent);
				return $parent_php;
			}
		}
		return null;
	}

	static function CreateShapePhp($shape) {
		if ($shape instanceof Java) {
			$type = "" . $shape->getClass();
			if ($type == "class com.aspose.slides.Shape") {
				$shape_php = new Shape($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.AutoShape") {
				$shape_php = new AutoShape($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Ellipse") {
				$shape_php = new Ellipse($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.GroupShape") {
				$shape_php = new GroupShape($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Table") {
				$shape_php = new Table($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Line") {
				$shape_php = new Line($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.PictureFrame") {
				$shape_php = new PictureFrame($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.AudioFrame") {
				$shape_php = new AudioFrame($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.OleObjectFrame") {
				$shape_php = new OleObjectFrame($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.VideoFrame") {
				$shape_php = new VideoFrame($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Polyline") {
				$shape_php = new Polyline($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Rectangle") {
				$shape_php = new Rectangle($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.Background") {
				$shape_php = new Background($shape);
				return $shape_php;
			}
			if ($type == "class com.aspose.slides.TextFrame") {
				$shape_php = new TextFrame($shape);
				return $shape_php;
			}
		}
		return null;
	}
}

// Interface AnchorText
// Represents the anchor text type.
define ("AnchorText_BOTTOM", 2);
define ("AnchorText_BOTTOM_BASELINE", 7);
define ("AnchorText_BOTTOM_CENTERED", 5);
define ("AnchorText_BOTTOM_CENTERED_BASELINE", 9);
define ("AnchorText_MIDDLE", 1);
define ("AnchorText_MIDDLE_CENTERED", 4);
define ("AnchorText_TOP", 0);
define ("AnchorText_TOP_BASELINE", 6);
define ("AnchorText_TOP_CENTERED", 3);
define ("AnchorText_TOP_CENTERED_BASELINE", 8);


// Interface AutoShapeType
// Represents the AutoShape type.
define ("AutoShapeType_ACTION_BUTTON_BACKOR_PREVIOUS", 194);
define ("AutoShapeType_ACTION_BUTTON_BEGINNING", 196);
define ("AutoShapeType_ACTION_BUTTON_CUSTOM", 189);
define ("AutoShapeType_ACTION_BUTTON_DOCUMENT", 198);
define ("AutoShapeType_ACTION_BUTTON_END", 195);
define ("AutoShapeType_ACTION_BUTTON_FORWARDOR_NEXT", 193);
define ("AutoShapeType_ACTION_BUTTON_HELP", 191);
define ("AutoShapeType_ACTION_BUTTON_HOME", 190);
define ("AutoShapeType_ACTION_BUTTON_INFORMATION", 192);
define ("AutoShapeType_ACTION_BUTTON_MOVIE", 200);
define ("AutoShapeType_ACTION_BUTTON_RETURN", 197);
define ("AutoShapeType_ACTION_BUTTON_SOUND", 199);
define ("AutoShapeType_ARC", 19);
define ("AutoShapeType_BALLOON", 17);
define ("AutoShapeType_BENT_ARROW", 91);
define ("AutoShapeType_BENT_UP_ARROW", 90);
define ("AutoShapeType_BEVEL", 84);
define ("AutoShapeType_BLOCK_ARC", 95);
define ("AutoShapeType_CAN", 22);
define ("AutoShapeType_CHEVRON", 55);
define ("AutoShapeType_CIRCULAR_ARROW", 99);
define ("AutoShapeType_CLOUD_CALLOUT", 106);
define ("AutoShapeType_CONNECTOR_CURVE", 38);
define ("AutoShapeType_CONNECTOR_CURVE_EXTRA_LONG", 40);
define ("AutoShapeType_CONNECTOR_CURVE_LONG", 39);
define ("AutoShapeType_CONNECTOR_CURVE_SHORT", 37);
define ("AutoShapeType_CONNECTOR_ELBOW", 34);
define ("AutoShapeType_CONNECTOR_ELBOW_EXTRA_LONG", 36);
define ("AutoShapeType_CONNECTOR_ELBOW_LONG", 35);
define ("AutoShapeType_CONNECTOR_ELBOW_SHORT", 33);
define ("AutoShapeType_CONNECTOR_STRAIGHT", 32);
define ("AutoShapeType_CROSS", 11);
define ("AutoShapeType_CUBE", 16);
define ("AutoShapeType_CURVED_DOWN_ARROW", 105);
define ("AutoShapeType_CURVED_DOWN_RIBBON", 107);
define ("AutoShapeType_CURVED_LEFT_ARROW", 103);
define ("AutoShapeType_CURVED_RIGHT_ARROW", 102);
define ("AutoShapeType_CURVED_UP_ARROW", 104);
define ("AutoShapeType_CURVED_UP_RIBBON", 108);
define ("AutoShapeType_DIAMOND", 4);
define ("AutoShapeType_DONUT", 23);
define ("AutoShapeType_DOUBLE_BRACE", 186);
define ("AutoShapeType_DOUBLE_BRACKET", 185);
define ("AutoShapeType_DOUBLE_WAVE", 188);
define ("AutoShapeType_DOWN_ARROW", 67);
define ("AutoShapeType_DOWN_ARROW_CALLOUT", 80);
define ("AutoShapeType_DOWN_RIBBON", 53);
define ("AutoShapeType_EXPLOSION1", 71);
define ("AutoShapeType_EXPLOSION2", 72);
define ("AutoShapeType_FLOWCHART_ALTERNATE_PROCESS", 176);
define ("AutoShapeType_FLOWCHART_CARD", 121);
define ("AutoShapeType_FLOWCHART_COLLATE", 125);
define ("AutoShapeType_FLOWCHART_CONNECTOR", 120);
define ("AutoShapeType_FLOWCHART_DATA", 111);
define ("AutoShapeType_FLOWCHART_Decision", 110);
define ("AutoShapeType_FLOWCHART_DELAY", 135);
define ("AutoShapeType_FLOWCHART_DIRECT_ACCESS_STORAGE", 133);
define ("AutoShapeType_FLOWCHART_DISPLAY", 134);
define ("AutoShapeType_FLOWCHART_DOCUMENT", 114);
define ("AutoShapeType_FLOWCHART_EXTRACT", 127);
define ("AutoShapeType_FLOWCHART_INTERNAL_STORAGE", 113);
define ("AutoShapeType_FLOWCHART_MAGNETIC_DISK", 132);
define ("AutoShapeType_FLOWCHART_MANUAL_INPUT", 118);
define ("AutoShapeType_FLOWCHART_MANUAL_OPERATION", 119);
define ("AutoShapeType_FLOWCHART_MERGE", 128);
define ("AutoShapeType_FLOWCHART_MULTIDOCUMENT", 115);
define ("AutoShapeType_FLOWCHART_OFFPAGE_CONNECTOR", 177);
define ("AutoShapeType_FLOWCHART_OR", 124);
define ("AutoShapeType_FLOWCHART_PREDEFINED_PROCESS", 112);
define ("AutoShapeType_FLOWCHART_PREPARATION", 117);
define ("AutoShapeType_FLOWCHART_PROCESS", 109);
define ("AutoShapeType_FLOWCHART_PUNCHED_TAPE", 122);
define ("AutoShapeType_FLOWCHART_SEQUENTIAL_ACCESS_STORAGE", 131);
define ("AutoShapeType_FLOWCHART_SORT", 126);
define ("AutoShapeType_FLOWCHART_STORED_DATA", 130);
define ("AutoShapeType_FLOWCHART_SUMMING_JUNCTION", 123);
define ("AutoShapeType_FLOWCHART_TERMINATOR", 116);
define ("AutoShapeType_FOLDED_CORNER", 65);
define ("AutoShapeType_HEART", 74);
define ("AutoShapeType_HEXAGON", 9);
define ("AutoShapeType_HORIZONTAL_SCROLL", 98);
define ("AutoShapeType_ISOSCELES_TRIANGLE", 5);
define ("AutoShapeType_LEFT_ARROW", 66);
define ("AutoShapeType_LEFT_ARROW_CALLOUT", 77);
define ("AutoShapeType_LEFT_BRACE", 87);
define ("AutoShapeType_LEFT_BRACKET", 85);
define ("AutoShapeType_LEFT_RIGHT_ARROW", 69);
define ("AutoShapeType_LEFT_RIGHT_ARROW_CALLOUT", 81);
define ("AutoShapeType_LEFT_RIGHT_UP_ARROW", 182);
define ("AutoShapeType_LEFT_UP_ARROW", 89);
define ("AutoShapeType_LIGHTNING_BOLT", 73);
define ("AutoShapeType_LINE_CALLOUT1", 180);
define ("AutoShapeType_LINE_CALLOUT1_ACCENT_BAR", 179);
define ("AutoShapeType_LINE_CALLOUT1_BORDERAND_ACCENT_BAR", 181);
define ("AutoShapeType_LINE_CALLOUT1_NO_BORDER", 178);
define ("AutoShapeType_LINE_CALLOUT2", 47);
define ("AutoShapeType_LINE_CALLOUT2_ACCENT_BAR", 44);
define ("AutoShapeType_LINE_CALLOUT2_BORDERAND_ACCENT_BAR", 50);
define ("AutoShapeType_LINE_CALLOUT2_NO_BORDER", 41);
define ("AutoShapeType_LINE_CALLOUT3", 48);
define ("AutoShapeType_LINE_CALLOUT3_ACCENT_BAR", 45);
define ("AutoShapeType_LINE_CALLOUT3_BORDERAND_ACCENT_BAR", 51);
define ("AutoShapeType_LINE_CALLOUT3_NO_BORDER", 42);
define ("AutoShapeType_LINE_CALLOUT4", 49);
define ("AutoShapeType_LINE_CALLOUT4_ACCENT_BAR", 46);
define ("AutoShapeType_LINE_CALLOUT4_BORDERAND_ACCENT_BAR", 52);
define ("AutoShapeType_LINE_CALLOUT4_NO_BORDER", 43);
define ("AutoShapeType_MOON", 184);
define ("AutoShapeType_NO_SYMBOL", 57);
define ("AutoShapeType_NOTCHED_RIGHT_ARROW", 94);
define ("AutoShapeType_OCTAGON", 10);
define ("AutoShapeType_OVAL_BALLOON", 100);
define ("AutoShapeType_OVAL_CALLOUT", 63);
define ("AutoShapeType_PARALLELOGRAM", 7);
define ("AutoShapeType_PENTAGON", 15);
define ("AutoShapeType_PLAQUE", 21);
define ("AutoShapeType_QUAD_ARROW", 76);
define ("AutoShapeType_QUAD_ARROW_CALLOUT", 83);
define ("AutoShapeType_RECTANGULAR_CALLOUT", 61);
define ("AutoShapeType_REGULAR_PENTAGON", 56);
define ("AutoShapeType_RIGHT_ARROW", 13);
define ("AutoShapeType_RIGHT_ARROW_CALLOUT", 78);
define ("AutoShapeType_RIGHT_BRACE", 88);
define ("AutoShapeType_RIGHT_BRACKET", 86);
define ("AutoShapeType_RIGHT_TRIANGLE", 6);
define ("AutoShapeType_ROUNDED_RECTANGLE", 2);
define ("AutoShapeType_ROUNDED_RECTANGULAR_CALLOUT", 62);
define ("AutoShapeType_SMILEY_FACE", 96);
define ("AutoShapeType_STAR16_POINT", 59);
define ("AutoShapeType_STAR24_POINT", 92);
define ("AutoShapeType_STAR32_POINT", 60);
define ("AutoShapeType_STAR4_POINT", 187);
define ("AutoShapeType_STAR5_POINT", 12);
define ("AutoShapeType_STAR8_POINT", 58);
define ("AutoShapeType_STRIPED_RIGHT_ARROW", 93);
define ("AutoShapeType_SUN", 183);
define ("AutoShapeType_TRAPEZOID", 8);
define ("AutoShapeType_U_TURN_ARROW", 101);
define ("AutoShapeType_UNKNOWN", -1);
define ("AutoShapeType_UP_ARROW", 68);
define ("AutoShapeType_UP_ARROW_CALLOUT", 79);
define ("AutoShapeType_UP_DOWN_ARROW", 70);
define ("AutoShapeType_UP_DOWN_ARROW_CALLOUT", 82);
define ("AutoShapeType_UP_RIBBON", 54);
define ("AutoShapeType_VERTICAL_SCROLL", 97);
define ("AutoShapeType_WAVE", 64);


// Interface BulletType
// Represents the type of the extended bullets.
define ("BulletType_NUMBERED", 2);
define ("BulletType_PICTURE", 0);
define ("BulletType_SYMBOL", 1);


// Interface DateTimeFormat
// Represents the date and time format for headers and footers.
define ("DateTimeFormat_DATETIME_ddddMMMMddyyyy", 1);
define ("DateTimeFormat_DATETIME_dMMMMyyyy", 2);
define ("DateTimeFormat_DATETIME_dMMMyy", 4);
define ("DateTimeFormat_DATETIME_FigureOut", 13);
define ("DateTimeFormat_DATETIME_Hmm", 9);
define ("DateTimeFormat_DATETIME_hmmAMPM", 11);
define ("DateTimeFormat_DATETIME_Hmmss", 10);
define ("DateTimeFormat_DATETIME_hmmssAMPM", 12);
define ("DateTimeFormat_DATETIME_Mdyy", 0);
define ("DateTimeFormat_DATETIME_MMddyyHmm", 7);
define ("DateTimeFormat_DATETIME_MMddyyhmmAMPM", 8);
define ("DateTimeFormat_DATETIME_MMMMdyyyy", 3);
define ("DateTimeFormat_DATETIME_MMMMyy", 5);
define ("DateTimeFormat_DATETIME_MMyy", 6);
define ("DateTimeFormat_UNKNOWN", -1);


// Interface FillType
// Represents the type of fill.
define ("FillType_GRADIENT", 2);
define ("FillType_NO_FILL", 0);
define ("FillType_NOT_SUPPORTED", -1);
define ("FillType_PATTERN", 4);
define ("FillType_PICTURE", 5);
define ("FillType_SOLID", 1);
define ("FillType_TEXTURE", 3);


// Interface FontCharSet
// Represents the character set.
define ("FontCharSet_ANSI_CHARSET", 0);
define ("FontCharSet_ARABIC_CHARSET", 178);
define ("FontCharSet_BALTIC_CHARSET", 186);
define ("FontCharSet_CHINESEBIG5_CHARSET", 136);
define ("FontCharSet_DEFAULT_CHARSET", 1);
define ("FontCharSet_EASTEUROPE_CHARSET", 238);
define ("FontCharSet_GB2312_CHARSET", 134);
define ("FontCharSet_GREEK_CHARSET", 161);
define ("FontCharSet_HANGEUL_CHARSET", 129);
define ("FontCharSet_HANGUL_CHARSET", 129);
define ("FontCharSet_HEBREW_CHARSET", 177);
define ("FontCharSet_JOHAB_CHARSET", 130);
define ("FontCharSet_MAC_CHARSET", 77);
define ("FontCharSet_OEM_CHARSET", 255);
define ("FontCharSet_RUSSIAN_CHARSET", 204);
define ("FontCharSet_SHIFTJIS_CHARSET", 128);
define ("FontCharSet_SYMBOL_CHARSET", 2);
define ("FontCharSet_THAI_CHARSET", 222);
define ("FontCharSet_TURKISH_CHARSET", 162);
define ("FontCharSet_VIETNAMESE_CHARSET", 163);


// Interface FontFamily
// Represents the font family.
define ("FontFamily_DECORATIVE", 80);
define ("FontFamily_DONTCARE", 0);
define ("FontFamily_MODERN", 48);
define ("FontFamily_ROMAN", 16);
define ("FontFamily_SCRIPT", 64);
define ("FontFamily_SWISS", 32);


// Interface FontPitch
// Represents the font pitch.
define ("FontPitch_DEFAULT_PITCH", 0);
define ("FontPitch_FIXED_PITCH", 1);
define ("FontPitch_MONO_FONT", 8);
define ("FontPitch_VARIABLE_PITCH", 2);


// Interface FontQuality
// Represents the font output quality.
define ("FontQuality_ANTIALIASED_QUALITY", 4);
define ("FontQuality_CLEARTYPE_QUALITY", 5);
define ("FontQuality_DEFAULT_QUALITY", 0);
define ("FontQuality_DRAFT_QUALITY", 1);
define ("FontQuality_NONANTIALIASED_QUALITY", 3);
define ("FontQuality_PROOF_QUALITY", 2);


// Interface FontRotationAngle
// Represents the angle of a font rotation.
define ("FontRotationAngle_DEGREE_0", 0);
define ("FontRotationAngle_DEGREE_180", 180);
define ("FontRotationAngle_DEGREE_270", 270);
define ("FontRotationAngle_DEGREE_90", 90);


// Interface GradientColorType
// Represents the gradient color type.
define ("GradientColorType_NOT_DEFINED", 0);
define ("GradientColorType_NOT_SUPPORTED", -1);
define ("GradientColorType_ONE_COLOR", 1);
define ("GradientColorType_TWO_COLORS", 2);


// Interface GradientStyle
// Represents the gradient style.
define ("GradientStyle_FROM_CENTER", 6);
define ("GradientStyle_FROM_CORNER1", 2);
define ("GradientStyle_FROM_CORNER2", 3);
define ("GradientStyle_FROM_CORNER3", 4);
define ("GradientStyle_FROM_CORNER4", 5);
define ("GradientStyle_NOT_DEFINED", 0);
define ("GradientStyle_NOT_SUPPORTED", -1);
define ("GradientStyle_STANDARD", 1);


// Interface ImageFormat
// Represents the image format.
define ("ImageFormat_DIB", 7);
define ("ImageFormat_EMF", 2);
define ("ImageFormat_JPEG", 5);
define ("ImageFormat_PICT", 4);
define ("ImageFormat_PNG", 6);
define ("ImageFormat_UNKNOWN", 1);
define ("ImageFormat_WMF", 3);


// Interface LineArrowheadLength
// Represents the length of an arrowhead.
define ("LineArrowheadLength_LONG", 2);
define ("LineArrowheadLength_MEDIUM", 1);
define ("LineArrowheadLength_SHORT", 0);


// Interface LineArrowheadStyle
// Represents the style of an arrowhead.
define ("LineArrowheadStyle_DIAMOND", 3);
define ("LineArrowheadStyle_NONE", 0);
define ("LineArrowheadStyle_OPEN", 5);
define ("LineArrowheadStyle_OVAL", 4);
define ("LineArrowheadStyle_STEALTH", 2);
define ("LineArrowheadStyle_TRIANGLE", 1);


// Interface LineArrowheadWidth
// Represents the width of an arrowhead.
define ("LineArrowheadWidth_MEDIUM", 1);
define ("LineArrowheadWidth_NARROW", 0);
define ("LineArrowheadWidth_WIDE", 2);


// Interface LineDashStyle
// Represents the dash style of a line.
define ("LineDashStyle_DASH", 1);
define ("LineDashStyle_DASH_DOT", 3);
define ("LineDashStyle_DASH_DOT_DOT", 4);
define ("LineDashStyle_DOT", 2);
define ("LineDashStyle_LONG_DASH", 6);
define ("LineDashStyle_LONG_DASH_DOT", 8);
define ("LineDashStyle_LONG_DASH_DOT_DOT", 10);
define ("LineDashStyle_LONG_DOT", 5);
define ("LineDashStyle_SOLID", 0);
define ("LineDashStyle_VERY_LONG_DASH", 7);
define ("LineDashStyle_VERY_LONG_DASH_DOT", 9);


// Interface LineStyle
// Represents the style of a line.
define ("LineStyle_SINGLE", 0);
define ("LineStyle_THICK_BETWEEN_THIN", 4);
define ("LineStyle_THICK_THIN", 3);
define ("LineStyle_THIN_THICK", 2);
define ("LineStyle_THIN_THIN", 1);


// Interface LinkActionType
// Represents the link action type.
define ("LinkActionType_CUSTOM_SHOW_ACTION", 7);
define ("LinkActionType_HYPER_LINK_ACTION", 4);
define ("LinkActionType_JUMP_ACTION", 3);
define ("LinkActionType_MACRO_ACTION", 1);
define ("LinkActionType_MEDIA_ACTION", 6);
define ("LinkActionType_NO_ACTION", 0);
define ("LinkActionType_OLE_ACTION", 5);
define ("LinkActionType_RUN_PROGRAM_ACTION", 2);


// Interface LinkJumpType
// Represents the link jump type.
define ("LinkJumpType_END_SHOW", 6);
define ("LinkJumpType_FIRST_SLIDE", 3);
define ("LinkJumpType_LAST_SLIDE", 4);
define ("LinkJumpType_LAST_SLIDE_VIEWED", 5);
define ("LinkJumpType_NEXT_SLIDE", 1);
define ("LinkJumpType_NO_JUMP", 0);
define ("LinkJumpType_PREVIOUS_SLIDE", 2);


// Interface NumberedBulletStyle
// Represents the style of the numbered bullets.
define ("NumberedBulletStyle_BULLET_ALPHA_LC_PAREN_BOTH", 8);
define ("NumberedBulletStyle_BULLET_ALPHA_LC_PAREN_RIGHT", 9);
define ("NumberedBulletStyle_BULLET_ALPHA_LC_PERIOD", 0);
define ("NumberedBulletStyle_BULLET_ALPHA_UC_PAREN_BOTH", 10);
define ("NumberedBulletStyle_BULLET_ALPHA_UC_PAREN_RIGHT", 11);
define ("NumberedBulletStyle_BULLET_ALPHA_UC_PERIOD", 1);
define ("NumberedBulletStyle_BULLET_ARABIC_ABJAD_DASH", 24);
define ("NumberedBulletStyle_BULLET_ARABIC_ALPHA_DASH", 23);
define ("NumberedBulletStyle_BULLET_ARABIC_DB_PERIOD", 29);
define ("NumberedBulletStyle_BULLET_ARABIC_DB_PLAIN", 28);
define ("NumberedBulletStyle_BULLET_ARABIC_PAREN_BOTH", 12);
define ("NumberedBulletStyle_BULLET_ARABIC_PAREN_RIGHT", 2);
define ("NumberedBulletStyle_BULLET_ARABIC_PERIOD", 3);
define ("NumberedBulletStyle_BULLET_ARABIC_PLAIN", 13);
define ("NumberedBulletStyle_BULLET_CIRCLE_NUM_DB_PLAIN", 18);
define ("NumberedBulletStyle_BULLET_CIRCLE_NUM_WD_BLACK_PLAIN", 20);
define ("NumberedBulletStyle_BULLET_CIRCLE_NUM_WD_WHITE_PLAIN", 19);
define ("NumberedBulletStyle_BULLET_HEBREW_ALPHA_DASH", 25);
define ("NumberedBulletStyle_BULLET_HINDI_ALFHA_PERIOD", 36);
define ("NumberedBulletStyle_BULLET_HINDI_NUM_PERIOD", 37);
define ("NumberedBulletStyle_BULLET_KANJI_KOREAN_PERIOD", 27);
define ("NumberedBulletStyle_BULLET_KANJI_KOREAN_PLAIN", 26);
define ("NumberedBulletStyle_BULLET_ROMAN_LC_PAREN_BOTH", 4);
define ("NumberedBulletStyle_BULLET_ROMAN_LC_PAREN_RIGHT", 5);
define ("NumberedBulletStyle_BULLET_ROMAN_LC_PERIOD", 6);
define ("NumberedBulletStyle_BULLET_ROMAN_UC_PAREN_BOTH", 14);
define ("NumberedBulletStyle_BULLET_ROMAN_UC_PAREN_RIGHT", 15);
define ("NumberedBulletStyle_BULLET_ROMAN_UC_PERIOD", 7);
define ("NumberedBulletStyle_BULLET_SIMP_CHIN_PERIOD", 17);
define ("NumberedBulletStyle_BULLET_SIMP_CHIN_PLAIN", 16);
define ("NumberedBulletStyle_BULLET_THAI_ALPHA_PAREN_BOTH", 32);
define ("NumberedBulletStyle_BULLET_THAI_ALPHA_PAREN_RIGHT", 31);
define ("NumberedBulletStyle_BULLET_THAI_ALPHA_PERIOD", 30);
define ("NumberedBulletStyle_BULLET_THAI_NUM_PAREN_BOTH", 35);
define ("NumberedBulletStyle_BULLET_THAI_NUM_PAREN_RIGHT", 34);
define ("NumberedBulletStyle_BULLET_THAI_NUM_PERIOD", 33);
define ("NumberedBulletStyle_BULLET_TRAD_CHIN_PERIOD", 22);
define ("NumberedBulletStyle_BULLET_TRAD_CHIN_PLAIN", 21);
define ("NumberedBulletStyle_BULLET_UNKNOWN", -1);


// Interface OleObjectType
// Represents the type of OLE Objects.
define ("OleObjectType_IMAGER", 9);
define ("OleObjectType_MEDIA_PLAYER", 15);
define ("OleObjectType_MICROSOFT_CLIPART_GALLERY", 1);
define ("OleObjectType_MICROSOFT_EQUATION_EDITOR", 6);
define ("OleObjectType_MICROSOFT_EXCEL", 3);
define ("OleObjectType_MICROSOFT_EXCEL_CHART", 14);
define ("OleObjectType_MICROSOFT_GRAPH", 4);
define ("OleObjectType_MICROSOFT_NOTE_IT_OLE", 13);
define ("OleObjectType_MICROSOFT_ORGANIZATION_CHART", 5);
define ("OleObjectType_MICROSOFT_PROJECT", 12);
define ("OleObjectType_MICROSOFT_WORD_TABLE", 2);
define ("OleObjectType_MICROSOFT_wordart", 7);
define ("OleObjectType_POWER_POINT_PRESENTATION", 10);
define ("OleObjectType_POWER_POINT_SLIDE", 11);
define ("OleObjectType_SOUND", 8);
define ("OleObjectType_UNKNOWN", 0);


// Interface PatternStyle
// Represents the pattern style.
define ("PatternStyle_DARK_DOWNWARD_DIAGONAL", 15);
define ("PatternStyle_DARK_HORIZONTAL", 13);
define ("PatternStyle_DARK_UPWARD_DIAGONAL", 16);
define ("PatternStyle_DARK_VERTICAL", 14);
define ("PatternStyle_DASHED_DOWNWARD_DIAGONAL", 28);
define ("PatternStyle_DASHED_HORIZONTAL", 32);
define ("PatternStyle_DASHED_UPWARD_DIAGONAL", 27);
define ("PatternStyle_DASHED_VERTICAL", 31);
define ("PatternStyle_DIAGONAL_BRICK", 40);
define ("PatternStyle_DIVOT", 46);
define ("PatternStyle_DOTTED_DIAMOND", 24);
define ("PatternStyle_DOTTED_GRID", 45);
define ("PatternStyle_HORIZONTAL_BRICK", 35);
define ("PatternStyle_LARGE_CHECKER_BOARD", 36);
define ("PatternStyle_LARGE_CONFETTI", 33);
define ("PatternStyle_LARGE_GRID", 34);
define ("PatternStyle_LIGHT_DOWNWARD_DIAGONAL", 21);
define ("PatternStyle_LIGHT_HORIZONTAL", 19);
define ("PatternStyle_LIGHT_UPWARD_DIAGONAL", 22);
define ("PatternStyle_LIGHT_VERTICAL", 20);
define ("PatternStyle_NARROW_HORIZONTAL", 30);
define ("PatternStyle_NARROW_VERTICAL", 29);
define ("PatternStyle_OUTLINED_DIAMOND", 41);
define ("PatternStyle_PERCENT05", 1);
define ("PatternStyle_PERCENT10", 2);
define ("PatternStyle_PERCENT20", 3);
define ("PatternStyle_PERCENT25", 4);
define ("PatternStyle_PERCENT30", 5);
define ("PatternStyle_PERCENT40", 6);
define ("PatternStyle_PERCENT50", 7);
define ("PatternStyle_PERCENT60", 8);
define ("PatternStyle_PERCENT70", 9);
define ("PatternStyle_PERCENT75", 10);
define ("PatternStyle_PERCENT80", 11);
define ("PatternStyle_PERCENT90", 12);
define ("PatternStyle_PLAID", 42);
define ("PatternStyle_SHINGLE", 47);
define ("PatternStyle_SMALL_CHECKER_BOARD", 17);
define ("PatternStyle_SMALL_CONFETTI", 37);
define ("PatternStyle_SMALL_GRID", 23);
define ("PatternStyle_SOLID_DIAMOND", 39);
define ("PatternStyle_SPHERE", 43);
define ("PatternStyle_TRELLIS", 18);
define ("PatternStyle_UNKNOWN", 0);
define ("PatternStyle_WAVE", 48);
define ("PatternStyle_WEAVE", 44);
define ("PatternStyle_WIDE_DOWNWARD_DIAGONAL", 25);
define ("PatternStyle_WIDE_UPWARD_DIAGONAL", 26);
define ("PatternStyle_ZIGZAG", 38);


// Interface PictureColorType
// Represents the picture color type.
define ("PictureColorType_AUTOMATIC", 0);
define ("PictureColorType_BLACK_AND_WHITE", 2);
define ("PictureColorType_GRAYSCALE", 1);
define ("PictureColorType_WATERMARK", 3);


// Interface PlaceholderType
// Represents the type of a placeholder.
define ("PlaceholderType_BODY", 14);
define ("PlaceholderType_CENTERED_Title1", 13);
define ("PlaceholderType_CENTERED_TITLE2", 15);
define ("PlaceholderType_CLIP_ART", 23);
define ("PlaceholderType_GENERIC_TEXT_OBJECT", 11);
define ("PlaceholderType_GRAPH", 21);
define ("PlaceholderType_MASTER_BODY", 2);
define ("PlaceholderType_MASTER_CENTERED_TITLE", 3);
define ("PlaceholderType_MASTER_DATE", 6);
define ("PlaceholderType_MASTER_FOOTER", 8);
define ("PlaceholderType_MASTER_HEADER", 9);
define ("PlaceholderType_MASTER_NOTES_BODY_IMAGE", 5);
define ("PlaceholderType_MASTER_NOTES_SLIDE_IMAGE", 4);
define ("PlaceholderType_MASTER_SLIDE_NUMBER", 7);
define ("PlaceholderType_MASTER_SUBTITLE", 10);
define ("PlaceholderType_MASTER_TITLE", 1);
define ("PlaceholderType_MEDIA_CLIP", 25);
define ("PlaceholderType_NONE", 0);
define ("PlaceholderType_NOTES_SLIDE_IMAGE", 19);
define ("PlaceholderType_OBJECT", 20);
define ("PlaceholderType_ORGANIZATION_CHART", 24);
define ("PlaceholderType_SUBTITLE", 16);
define ("PlaceholderType_TABLE", 22);
define ("PlaceholderType_TITLE", 12);
define ("PlaceholderType_VERTICAL_TEXT_BODY", 18);
define ("PlaceholderType_VERTICAL_TEXT_TITLE", 17);


// Interface SegmentType
// Represents the polyline segment type.
define ("SegmentType_CLOSE_POLYGON", 3);
define ("SegmentType_CURVE", 1);
define ("SegmentType_LINE", 0);
define ("SegmentType_NEW_POLYGON", 2);


// Interface ShapeAdvanceMode
// Represents the advance mode for the shapes.
define ("ShapeAdvanceMode_ADVANCE_ON_CLICK", 0);
define ("ShapeAdvanceMode_ADVANCE_ON_TIME", 1);


// Interface ShapeAfterEffect
// Represents the effect how shape appiers after animation.
define ("ShapeAfterEffect_DIM", 1);
define ("ShapeAfterEffect_HIDE", 3);
define ("ShapeAfterEffect_HIDE_ON_CLICK", 2);
define ("ShapeAfterEffect_NOTHING", 0);


// Interface ShapeEntryEffect
// Represents the type of shape entry effect.
define ("ShapeEntryEffect_BLINDS_HORIZONTAL", 201);
define ("ShapeEntryEffect_BLINDS_VERTICAL", 200);
define ("ShapeEntryEffect_BOX_IN", 1101);
define ("ShapeEntryEffect_BOX_OUT", 1100);
define ("ShapeEntryEffect_CHECKERBOARD_ACROSS", 300);
define ("ShapeEntryEffect_CHECKERBOARD_DOWN", 301);
define ("ShapeEntryEffect_CIRCLE_OUT", 2700);
define ("ShapeEntryEffect_CROWL_FROM_DOWN", 1215);
define ("ShapeEntryEffect_CROWL_FROM_LEFT", 1212);
define ("ShapeEntryEffect_CROWL_FROM_RIGHT", 1214);
define ("ShapeEntryEffect_CROWL_FROM_UP", 1213);
define ("ShapeEntryEffect_CUT", 0);
define ("ShapeEntryEffect_DIAMOND_OUT", 1700);
define ("ShapeEntryEffect_DISSOLVE", 500);
define ("ShapeEntryEffect_FLASH_ONCE_FAST", 1400);
define ("ShapeEntryEffect_FLASH_ONCE_MEDIUM", 1401);
define ("ShapeEntryEffect_FLASH_ONCE_SLOW", 1402);
define ("ShapeEntryEffect_FLY_FROM_BOTTOM", 1203);
define ("ShapeEntryEffect_FLY_FROM_BOTTOM_LEFT", 1206);
define ("ShapeEntryEffect_FLY_FROM_BOTTOM_RIGHT", 1207);
define ("ShapeEntryEffect_FLY_FROM_LEFT", 1200);
define ("ShapeEntryEffect_FLY_FROM_RIGHT", 1202);
define ("ShapeEntryEffect_FLY_FROM_TOP", 1201);
define ("ShapeEntryEffect_FLY_FROM_TOP_LEFT", 1204);
define ("ShapeEntryEffect_FLY_FROM_TOP_RIGHT", 1205);
define ("ShapeEntryEffect_NONE", -1);
define ("ShapeEntryEffect_PEEK_FROM_DOWN", 1209);
define ("ShapeEntryEffect_PEEK_FROM_LEFT", 1208);
define ("ShapeEntryEffect_PEEK_FROM_RIGHT", 1210);
define ("ShapeEntryEffect_PEEK_FROM_UP", 1211);
define ("ShapeEntryEffect_RANDOM", 100);
define ("ShapeEntryEffect_RANDOM_BARS_HORIZONTAL", 800);
define ("ShapeEntryEffect_RANDOM_BARS_VERTICAL", 801);
define ("ShapeEntryEffect_RANDOM_XP", 101);
define ("ShapeEntryEffect_SPIRAL", 1228);
define ("ShapeEntryEffect_SPLIT_HORIZONTAL_IN", 1301);
define ("ShapeEntryEffect_SPLIT_HORIZONTAL_OUT", 1300);
define ("ShapeEntryEffect_SPLIT_VERTICAL_IN", 1303);
define ("ShapeEntryEffect_SPLIT_VERTICAL_OUT", 1302);
define ("ShapeEntryEffect_STRETCH_ACROSS", 1222);
define ("ShapeEntryEffect_STRETCH_DOWN", 1226);
define ("ShapeEntryEffect_STRETCH_LEFT", 1223);
define ("ShapeEntryEffect_STRETCH_RIGHT", 1225);
define ("ShapeEntryEffect_STRETCH_UP", 1224);
define ("ShapeEntryEffect_STRIPS_LEFT_DOWN", 906);
define ("ShapeEntryEffect_STRIPS_LEFT_UP", 904);
define ("ShapeEntryEffect_STRIPS_RIGHT_DOWN", 907);
define ("ShapeEntryEffect_STRIPS_RIGHT_UP", 905);
define ("ShapeEntryEffect_SWIVEL", 1227);
define ("ShapeEntryEffect_WEDGE", 1900);
define ("ShapeEntryEffect_WHEEL1_SPOKE", 2601);
define ("ShapeEntryEffect_WHEEL2_SPOKES", 2602);
define ("ShapeEntryEffect_WHEEL3_SPOKES", 2603);
define ("ShapeEntryEffect_WHEEL4_SPOKES", 2604);
define ("ShapeEntryEffect_WHEEL8_SPOKES", 2608);
define ("ShapeEntryEffect_WIPE_DOWN", 1003);
define ("ShapeEntryEffect_WIPE_LEFT", 1000);
define ("ShapeEntryEffect_WIPE_RIGHT", 1002);
define ("ShapeEntryEffect_WIPE_UP", 1001);
define ("ShapeEntryEffect_ZOOM_BOTTOM", 1221);
define ("ShapeEntryEffect_ZOOM_CENTER", 1220);
define ("ShapeEntryEffect_ZOOM_IN", 1216);
define ("ShapeEntryEffect_ZOOM_IN_SLIGHTLY", 1217);
define ("ShapeEntryEffect_ZOOM_OUT", 1218);
define ("ShapeEntryEffect_ZOOM_OUT_SLIGHTLY", 1219);


// Interface SlideLayout
// Represents the slide layout.
define ("SlideLayout_BIG_OBJECT", 15);
define ("SlideLayout_BLANK_SLIDE", 16);
define ("SlideLayout_FOUR_OBJECTS", 14);
define ("SlideLayout_HAND_OUT_LAYOUT", 6);
define ("SlideLayout_MASTER_NOTES_LAYOUT", 4);
define ("SlideLayout_MASTER_SLIDE_LAYOUT", 3);
define ("SlideLayout_NOTES_TITLE_OR_BODY_LAYOUT", 5);
define ("SlideLayout_ONLY_TITLE_PLACE_HOLDER", 7);
define ("SlideLayout_TITLE_AND_BODY_SLIDE", 1);
define ("SlideLayout_TITLE_AND_TWO_COLUMNS", 8);
define ("SlideLayout_TITLE_AND_TWO_ROWS", 9);
define ("SlideLayout_TITLE_MASTER_SLIDE", 2);
define ("SlideLayout_TITLE_SLIDE", 0);
define ("SlideLayout_TWO_COLUMNS_LEFT_COLUMN_HAS_TWO_ROWS", 11);
define ("SlideLayout_TWO_COLUMNS_RIGHT_COLUMN_HAS_TWO_ROWS", 10);
define ("SlideLayout_TWO_ROWS_BOTTON_ROW_HAS_TWO_COLUMNS", 12);
define ("SlideLayout_TWO_ROWS_TOP_ROW_HAS_TWO_COLUMNS", 13);
define ("SlideLayout_VERTICAL_TITLE_ON_THE_RIGHT_BODY_ON_THE_LEFT", 17);
define ("SlideLayout_VERTICAL_TITLE_ON_THE_RIGHT_BODY_ON_THE_LEFT_SPLIT_INTO_TWO_ROWS", 18);


// Interface SlideShowRangeType
// Represents the range type of a slide show.
define ("SlideShowRangeType_SHOW_ALL", 0);
define ("SlideShowRangeType_SHOW_NAMED_SLIDE_SHOW", 1);
define ("SlideShowRangeType_SHOW_SLIDE_RANGE", 2);


// Interface SlideShowType
// Represents the type of a slide show.
define ("SlideShowType_SHOW_TYPE_KIOSK", 0);
define ("SlideShowType_SHOW_TYPE_SPEAKER", 1);
define ("SlideShowType_SHOW_TYPE_WINDOW", 2);


// Interface SlideSizeType
// Represents the slide size.
define ("SlideSizeType_A4_PAPER", 2);
define ("SlideSizeType_BANNER", 5);
define ("SlideSizeType_CUSTOM", 6);
define ("SlideSizeType_LETTER_PAPER", 1);
define ("SlideSizeType_ON_SCREEN", 0);
define ("SlideSizeType_OVERHEAD", 4);
define ("SlideSizeType_SLIDE_35MM", 3);


// Interface SlideTransitionEffect
// Represents the type of slide transition.
define ("SlideTransitionEffect_BLINDS_HORIZONTAL", 201);
define ("SlideTransitionEffect_BLINDS_VERTICAL", 200);
define ("SlideTransitionEffect_BOX_IN", 1101);
define ("SlideTransitionEffect_BOX_OUT", 1100);
define ("SlideTransitionEffect_CHECERBOARD_ACROSS", 300);
define ("SlideTransitionEffect_CHECERBOARD_DOWN", 301);
define ("SlideTransitionEffect_CIRCLE_OUT", 2700);
define ("SlideTransitionEffect_COMB_HORIZONTAL", 2100);
define ("SlideTransitionEffect_COMB_VERTICAL", 2101);
define ("SlideTransitionEffect_COVER_DOWN", 403);
define ("SlideTransitionEffect_COVER_LEFT", 400);
define ("SlideTransitionEffect_COVER_LEFT_DOWN", 406);
define ("SlideTransitionEffect_COVER_LEFT_UP", 404);
define ("SlideTransitionEffect_COVER_RIGHT", 402);
define ("SlideTransitionEffect_COVER_RIGHT_DOWN", 407);
define ("SlideTransitionEffect_COVER_RIGHT_UP", 405);
define ("SlideTransitionEffect_COVER_UP", 401);
define ("SlideTransitionEffect_CUT", 0);
define ("SlideTransitionEffect_CUT_THROUGH_BLACK", 1);
define ("SlideTransitionEffect_DIAMOND_OUT", 1700);
define ("SlideTransitionEffect_DISSOLVE", 500);
define ("SlideTransitionEffect_FADE", 600);
define ("SlideTransitionEffect_FADE_SMOOTHLY", 2300);
define ("SlideTransitionEffect_NEWS_FLASH", 2200);
define ("SlideTransitionEffect_NONE", 2);
define ("SlideTransitionEffect_PLUS_OUT", 1800);
define ("SlideTransitionEffect_PUSH_DOWN", 2003);
define ("SlideTransitionEffect_PUSH_LEFT", 2000);
define ("SlideTransitionEffect_PUSH_RIGHT", 2002);
define ("SlideTransitionEffect_PUSH_UP", 2001);
define ("SlideTransitionEffect_RANDOM", 101);
define ("SlideTransitionEffect_RANDOM_BARS_HORIZONTAL", 800);
define ("SlideTransitionEffect_RANDOM_BARS_VERTICAL", 801);
define ("SlideTransitionEffect_SPLIT_HORIZONTAL_IN", 1301);
define ("SlideTransitionEffect_SPLIT_HORIZONTAL_OUT", 1300);
define ("SlideTransitionEffect_SPLIT_VERTICAL_IN", 1303);
define ("SlideTransitionEffect_SPLIT_VERTICAL_OUT", 1302);
define ("SlideTransitionEffect_STRIPS_LEFT_DOWN", 906);
define ("SlideTransitionEffect_STRIPS_LEFT_UP", 904);
define ("SlideTransitionEffect_STRIPS_RIGHT_DOWN", 907);
define ("SlideTransitionEffect_STRIPS_RIGHT_UP", 905);
define ("SlideTransitionEffect_UNCOVER_DOWN", 703);
define ("SlideTransitionEffect_UNCOVER_LEFT", 700);
define ("SlideTransitionEffect_UNCOVER_LEFT_DOWN", 706);
define ("SlideTransitionEffect_UNCOVER_LEFT_UP", 704);
define ("SlideTransitionEffect_UNCOVER_RIGHT", 702);
define ("SlideTransitionEffect_UNCOVER_RIGHT_DOWN", 707);
define ("SlideTransitionEffect_UNCOVER_RIGHT_UP", 705);
define ("SlideTransitionEffect_UNCOVER_UP", 701);
define ("SlideTransitionEffect_WEDGE", 1900);
define ("SlideTransitionEffect_WHEEL1_SPOKE", 2601);
define ("SlideTransitionEffect_WHEEL2_SPOKES", 2602);
define ("SlideTransitionEffect_WHEEL3_SPOKES", 2603);
define ("SlideTransitionEffect_WHEEL4_SPOKES", 2604);
define ("SlideTransitionEffect_WHEEL8_SPOKES", 2608);
define ("SlideTransitionEffect_WIPE_DOWN", 1003);
define ("SlideTransitionEffect_WIPE_LEFT", 1000);
define ("SlideTransitionEffect_WIPE_RIGHT", 1002);
define ("SlideTransitionEffect_WIPE_UP", 1001);


// Interface SlideTransitionSpeed
// Represents the speed of slide transition.
define ("SlideTransitionSpeed_FAST", 2);
define ("SlideTransitionSpeed_MEDIUM", 1);
define ("SlideTransitionSpeed_SLOW", 0);


// Interface SlideViewType
// Represents the slide view type.
define ("SlideViewType_NONE", 0);
define ("SlideViewType_NOTES", 3);
define ("SlideViewType_OUTLINE_VIEW", 2);
define ("SlideViewType_SLIDEVIEW", 1);


// Interface TabAlignment
// Represents the tab alignment.
define ("TabAlignment_CENTER", 1);
define ("TabAlignment_DECIMAL", 3);
define ("TabAlignment_LEFT", 0);
define ("TabAlignment_RIGHT", 2);


// Interface TextAlignment
// Represents the text alignment.
define ("TextAlignment_CENTER", 1);
define ("TextAlignment_DEFAULT", -1);
define ("TextAlignment_LEFT", 0);
define ("TextAlignment_RIGHT", 2);


// Interface TextLevelEffect
// Represents the paragraphs level for text animation.
define ("TextLevelEffect_ANIMATE_BY_ALL_LEVELS", 1);
define ("TextLevelEffect_ANIMATE_BY_FIFTH_LEVEL", 6);
define ("TextLevelEffect_ANIMATE_BY_FIRST_LEVEL", 2);
define ("TextLevelEffect_ANIMATE_BY_FOURTH_LEVEL", 5);
define ("TextLevelEffect_ANIMATE_BY_SECOND_LEVEL", 3);
define ("TextLevelEffect_ANIMATE_BY_THIRD_LEVEL", 4);


// Interface TextUnitEffect
// Represents the units for text animation.
define ("TextUnitEffect_ANIMATE_BY_CHARACTER", 2);
define ("TextUnitEffect_ANIMATE_BY_PARAGRAPH", 0);
define ("TextUnitEffect_ANIMATE_BY_WORD", 1);


// Interface TextureStyle
// Represents the standard texture styles.
define ("TextureStyle_BLUE_TISSUE_PAPER", 17);
define ("TextureStyle_BOUQUET", 20);
define ("TextureStyle_BROWN_MARBLE", 11);
define ("TextureStyle_CANVAS", 2);
define ("TextureStyle_CORC", 21);
define ("TextureStyle_DENIM", 3);
define ("TextureStyle_FISH_FOSSIL", 7);
define ("TextureStyle_GRANITE", 12);
define ("TextureStyle_GREEN_MARBLE", 9);
define ("TextureStyle_MEDIUM_WOOD", 24);
define ("TextureStyle_NEWSPRINT", 13);
define ("TextureStyle_OAK", 23);
define ("TextureStyle_PAPER_BAG", 6);
define ("TextureStyle_PAPYRUS", 1);
define ("TextureStyle_PARCHMENT", 15);
define ("TextureStyle_PINK_TISSUE_PAPER", 18);
define ("TextureStyle_PURPLE_MESH", 19);
define ("TextureStyle_RECYCLED_PAPER", 14);
define ("TextureStyle_SAND", 8);
define ("TextureStyle_STATIONERY", 16);
define ("TextureStyle_WALNUT", 22);
define ("TextureStyle_WATER_DROPLETS", 5);
define ("TextureStyle_WHITE_MARBLE", 10);
define ("TextureStyle_WOVEN_MAT", 4);


// Interface ZOrderCmd
// Represents where to move the specified shape relative to the other shapes.
define ("ZOrderCmd_BRING_FORWARD", 0);
define ("ZOrderCmd_BRING_TO_FRONT", 1);
define ("ZOrderCmd_SEND_BACKWARD", 2);
define ("ZOrderCmd_SEND_TO_BACK", 3);

// Represents a collection of custom document properties.
class DocumentProperties {

	public $m_documentProperties;

	function __construct($props) {
		$this->m_documentProperties = $props;
	}

	// Determines whether the collection contains a property with the specified name.
	function contains($string) {
		$boolean = $this->m_documentProperties->contains($string);
		return $boolean;
	}

	// Returns the property associated with a specific name.
	function get($string) {
		$object = $this->m_documentProperties->get($string);
		return $object;
	}

	// Gets a property name at the specified index of the collection.
	function getPropertyName($int) {
		$string = $this->m_documentProperties->getPropertyName($int);
		return $string;
	}

	// Returns the number of custom properties actually contained in the collection.
	function size() {
		$int = $this->m_documentProperties->size();
		return $int;
	}
}

// Represents pseudo collection of Tab items.
// Can be used as generator of tabulation.
// Almost endless, but beware of Tab.getPosition() overflow.
class EffectiveTabs {

	public $m_effectiveTabs;

	function __construct($etabs) {
		$this->m_effectiveTabs = $etabs;
	}

	// Returns the distance between two closest implicit tab positions.
	function getDefaultTabSize() {
		$int = $this->m_effectiveTabs->getDefaultTabSize();
		return $int;
	}

	// Returns the number of explicitly defined tabs.
	function getExplicitTabCount() {
		$int = $this->m_effectiveTabs->getExplicitTabCount();
		return $int;
	}

	// Returns the next tab with position greater or equal to specified.
	function getTabAfterPosition($int) {
		$tab = $this->m_effectiveTabs->getTabAfterPosition($int);
		$tab_php = new Tab($tab);
		return $tab_php;
	}

	// Returns explicitly defined tab if index less than ExplicitTabCount otherwise generates new implicit tab using DefaultTabSize.
	function getTabByIndex($int) {
		$tab = $this->m_effectiveTabs->getTabByIndex($int);
		$tab_php = new Tab($tab);
		return $tab_php;
	}
}

// Represents the Ellipse shape.
class Ellipse extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}
}

// Represents a fill formatting.
class FillFormat {

	public $m_fillFormat;

	function __construct($fformat) {
		$this->m_fillFormat = $fformat;
	}

	// Returns the background color for the current fill type.
	// java.awt.Color
	function getBackColor() {
		$color = $this->m_fillFormat->getBackColor();
		return $color;
	}

	// Returns the foreground color for the current fill type.
	// java.awt.Color
	function getForeColor() {
		$color = $this->m_fillFormat->getForeColor();
		return $color;
	}

	// Returns the gradient color type for the current gradient.
	function getGradientColorType() {
		$int = $this->m_fillFormat->getGradientColorType();
		return $int;
	}

	// Returns the gradient degree for the ONE_COLOR gradients.
	// 0-19 values. 0 - black, 19 - white.
	function getGradientDegree() {
		$int = $this->m_fillFormat->getGradientDegree();
		return $int;
	}

	// Returns the fill angle (0-179).
	function getGradientFillAngle() {
		$int = $this->m_fillFormat->getGradientFillAngle();
		return $int;
	}

	// Returns the fill focus shift for a gradients.
	function getGradientFillFocus() {
		$int = $this->m_fillFormat->getGradientFillFocus();
		return $int;
	}

	// Returns the gradient style for the current gradient.
	function getGradientStyle() {
		$int = $this->m_fillFormat->getGradientStyle();
		return $int;
	}

	// Returns the pattern style.
	function getPatternStyle() {
		$int = $this->m_fillFormat->getPatternStyle();
		return $int;
	}

	// Returns the picture id for the picture fill style.
	function getPictureId() {
		$int = $this->m_fillFormat->getPictureId();
		return $int;
	}

	// Returns the fill type for a shape.
	function getType() {
		$int = $this->m_fillFormat->getType();
		return $int;
	}

	// Sets the background color for the current fill type.
	// java.awt.Color
	function setBackColor($color) {
		$this->m_fillFormat->setBackColor($color);
	}

	// Sets the foreground color for the current fill type.
	// java.awt.Color
	function setForeColor($color) {
		$this->m_fillFormat->setForeColor($color);
	}

	// Sets the gradient color type for the current gradient.
	function setGradientColorType($int) {
		$this->m_fillFormat->setGradientColorType($int);
	}

	// Sets the gradient degree for the ONE_COLOR gradients.
	// 0-19 values. 0 - black, 19 - white.
	function setGradientDegree($int) {
		$this->m_fillFormat->setGradientDegree($int);
	}

	// Sets the fill angle (0-179).
	function setGradientFillAngle($int) {
		$this->m_fillFormat->setGradientFillAngle($int);
	}

	// Sets the fill focus shift for a gradients.
	function setGradientFillFocus($int) {
		$this->m_fillFormat->setGradientFillFocus($int);
	}

	// Sets the gradient style for the current gradient.
	function setGradientStyle($int) {
		$this->m_fillFormat->setGradientStyle($int);
	}

	// Sets the pattern style.
	function setPatternStyle($int) {
		$this->m_fillFormat->setPatternStyle($int);
	}

	// Sets the picture id for the picture fill style.
	function setPictureId($int) {
		$this->m_fillFormat->setPictureId($int);
	}

	// Sets the texture style.
	function setTextureStyle($int) {
		$this->m_fillFormat->setTextureStyle($int);
	}

	// Sets the fill type for a shape.
	function setType($int) {
		$this->m_fillFormat->setType($int);
	}
}

// Represents the font used in a presentation.
class FontEntity {

	public $m_fontEntity;

	function __construct($font) {
		$this->m_fontEntity = $font;
	}

	// Compares this object to the specified object.
	function equals($font) {
		$boolean = $this->m_fontEntity->equals($font->m_fontEntity);
		return $boolean;
	}

	// Returns the charset for the font.
	function getCharSet() {
		$int = $this->m_fontEntity->getCharSet();
		return $int;
	}

	// Returns the font family.
	function getFamily() {
		$int = $this->m_fontEntity->getFamily();
		return $int;
	}

	// Returns the index of a font.
	function getFontIndex() {
		$int = $this->m_fontEntity->getFontIndex();
		return $int;
	}

	// Returns the font name.
	function getFontName() {
		$string = $this->m_fontEntity->getFontName();
		return $string;
	}

	// Returns the font pitch.
	function getPitch() {
		$int = $this->m_fontEntity->getPitch();
		return $int;
	}

	// Returns the font quality.
	function getQuality() {
		$int = $this->m_fontEntity->getQuality();
		return $int;
	}

	// Sets the font charset.
	function setCharSet($int) {
		$this->m_fontEntity->setCharSet($int);
	}

	// Sets the font family.
	function setFamily($byte) {
		$this->m_fontEntity->setFamily($byte);
	}

	// Sets the font name.
	function setFontName($string) {
		$this->m_fontEntity->setFontName($string);
	}

	// Sets the font pitch.
	function setPitch($byte) {
		$this->m_fontEntity->setPitch($byte);
	}

	// Sets the font quality.
	function setQuality($int) {
		$this->m_fontEntity->setQuality($int);
	}
}

// Represents the collection of a fonts used in a presentation.
class Fonts {

	public $m_fonts;

	function __construct($fonts) {
		$this->m_fonts = $fonts;
	}

	// Adds a Font to the end of collection.
	function add($fontEntity) {
		$int = $this->m_fonts->add($fontEntity->m_fontEntity);
		return $int;
	}

	// Removes all elements from the collection.
	function clear() {
		$this->m_fonts->clear();
	}

	// Returns the font by font index.
	function get($index) {
		$fontEntity = $this->m_fonts->get($index);
		$fontEntity_php = new FontEntity($fontEntity);
		return $fontEntity_php;
	}

	// Removes the element at the specified index of the collection.
	function remove($int) {
		$this->m_fonts->remove($int);
	}

	// Returns the number of elements in this collection.
	function size() {
		$int = $this->m_fonts->size();
		return $int;
	}
}

// Represents the group of a shapes on a slide.
class GroupShape extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns the collection of shapes inside the group.
	function getShapes() {
		$shapes = $this->m_shape->getShapes();
		$shapes_php = new Shapes($shapes);
		return $shapes_php;
	}
}

// Represents the header, footer, slide number, date and time on a slide.
class HeaderFooter {

	public $m_headerFooter;

	function __construct($hf) {
		$this->m_headerFooter = $hf;
	}

	// Returns the format of a datetime on a slide.
	function getDateTimeFormat() {
		$int = $this->m_headerFooter->getDateTimeFormat();
		return $int;
	}

	// Returns the fixed datetime text for a slide.
	function getDateTimeText() {
		$string = $this->m_headerFooter->getDateTimeText();
		return $string;
	}

	// Returns the footer text for a slide.
	function getFooterText() {
		$string = $this->m_headerFooter->getFooterText();
		return $string;
	}

	// Returns the header text for a slide.
	function getHeaderText() {
		$string = $this->m_headerFooter->getHeaderText();
		return $string;
	}

	// Determines whether the datetime is a fixed text.
	function isDateTimeFixed() {
		$boolean = $this->m_headerFooter->isDateTimeFixed();
		return $boolean;
	}

	// Determines whether the datetime is visible on a slide.
	function isDateTimeVisible() {
		$boolean = $this->m_headerFooter->isDateTimeVisible();
		return $boolean;
	}

	// Determines whether the footer is visible on a slide.
	function isFooterVisible() {
		$boolean = $this->m_headerFooter->isFooterVisible();
		return $boolean;
	}

	// Determines whether the header is visible on a slide.
	function isHeaderVisible() {
		$boolean = $this->m_headerFooter->isHeaderVisible();
		return $boolean;
	}

	// Determines whether the page number is visible on a slide.
	function isPageNumberVisible() {
		$boolean = $this->m_headerFooter->isPageNumberVisible();
		return $boolean;
	}

	// Determines whether the header, footer, page number and
	// datetime are visible on a title slide.
	function isShowOnTitleSlide() {
		$boolean = $this->m_headerFooter->isShowOnTitleSlide();
		return $boolean;
	}
}

// Provides methods to license the component.
class License {

	public $m_license;

	function License($license) {
		$this->m_license = $license;
	}

	// Licenses the component.
	function setLicense($input) {
		if (is_string($input)) {
			$input_file = new Java('java.io.File', $input);
			$input_stream = new Java('java.io.FileInputStream', $input_file);
			$this->m_license->setLicense($input_stream);
			$input_stream->close();
		} else {
			$this->m_license->setLicense($input);
		}
	}
}

// Represents the Line shape.
class Line extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns the end point of a line.
	// java.awt.Point
	function getEndPoint() {
		$point = $this->m_shape->getEndPoint();
		return $point;
	}

	// Returns the start point of a line.
	// java.awt.Point
	function getStartPoint() {
		$point = $this->m_shape->getStartPoint();
		return $point;
	}

	// Sets the end point of a line.
	// java.awt.Point
	function setEndPoint($point) {
		$this->m_shape->setEndPoint($point);
	}

	// Sets the start point of a line.
	// java.awt.Point
	function setStartPoint($point) {
		$this->m_shape->setStartPoint($point);
	}
}

// Represents a line and arrowhead formatting.
class LineFormat {

	public $m_lineFormat;

	function __construct($lformat) {
		$this->m_lineFormat = $lformat;
	}

	// Returns the length of an arrowhead at the begin of a line.
	function getBeginArrowheadLength() {
		$int = $this->m_lineFormat->getBeginArrowheadLength();
		return $int;
	}

	// Returns the arrowhead style at the begin of a line.
	function getBeginArrowheadStyle() {
		$int = $this->m_lineFormat->getBeginArrowheadStyle();
		return $int;
	}

	// Returns the width of an arrowhead at the begin of a line.
	function getBeginArrowheadWidth() {
		$int = $this->m_lineFormat->getBeginArrowheadWidth();
		return $int;
	}

	// Returns the dash style of a line.
	function getDashStyle() {
		$int = $this->m_lineFormat->getDashStyle();
		return $int;
	}

	// Returns the length of an arrowhead at the end of a line.
	function getEndArrowheadLength() {
		$int = $this->m_lineFormat->getEndArrowheadLength();
		return $int;
	}

	// Returns the arrowhead style at the end of a line.
	function getEndArrowheadStyle() {
		$int = $this->m_lineFormat->getEndArrowheadStyle();
		return $int;
	}

	// Returns the width of an arrowhead at the end of a line.
	function getEndArrowheadWidth() {
		$int = $this->m_lineFormat->getEndArrowheadWidth();
		return $int;
	}

	// Returns the foreground color of a line.
	// java.awt.Color
	function getForeColor() {
		$color = $this->m_lineFormat->getForeColor();
		return $color;
	}

	// Returns the style of a line.
	function getStyle() {
		$int = $this->m_lineFormat->getStyle();
		return $int;
	}

	// Returns the width of a line.
	function getWidth() {
		$double = $this->m_lineFormat->getWidth();
		return $double;
	}

	// Determines whether the line has rounded caps.
	function isRoundEndCap() {
		$boolean = $this->m_lineFormat->isRoundEndCap();
		return $boolean;
	}

	// Determines whether the lines on a shape are visible.
	function isShowLines() {
		$boolean = $this->m_lineFormat->isShowLines();
		return $boolean;
	}

	// Sets the length of an arrowhead at the begin of a line.
	function setBeginArrowheadLength($int) {
		$this->m_lineFormat->setBeginArrowheadLength($int);
	}

	// Sets the arrowhead style at the begin of a line.
	function setBeginArrowheadStyle($int) {
		$this->m_lineFormat->setBeginArrowheadStyle($int);
	}

	// Sets the width of an arrowhead at the begin of a line.
	function setBeginArrowheadWidth($int) {
		$this->m_lineFormat->setBeginArrowheadWidth($int);
	}

	// Sets the dash style of a line.
	function setDashStyle($int) {
		$this->m_lineFormat->setDashStyle($int);
	}

	// Sets the length of an arrowhead at the end of a line.
	function setEndArrowheadLength($int) {
		$this->m_lineFormat->setEndArrowheadLength($int);
	}

	// Sets the arrowhead style at the end of a line.
	function setEndArrowheadStyle($int) {
		$this->m_lineFormat->setEndArrowheadStyle($int);
	}

	// Sets the width of an arrowhead at the end of a line.
	function setEndArrowheadWidth($int) {
		$this->m_lineFormat->setEndArrowheadWidth($int);
	}

	// Sets the foreground color of a line.
	// java.awt.Color
	function setForeColor($color) {
		$this->m_lineFormat->setForeColor($color);
	}

	// Sets the style of a line caps.
	function setRoundEndCap($boolean) {
		$this->m_lineFormat->setRoundEndCap($boolean);
	}

	// Change visibility of the lines on a shape.
	function setShowLines($boolean) {
		$this->m_lineFormat->setShowLines($boolean);
	}

	// Sets the style of a line.
	function setStyle($int) {
		$this->m_lineFormat->setStyle($int);
	}

	// Sets the width of a line.
	function setWidth($double) {
		$this->m_lineFormat->setWidth($double);
	}
}

// Represents the hyperlink in a text.
class Link {

	public $m_link;

	function __construct($link) {
		$this->m_link = $link;
	}

	// Returns action type for a link.
	function getActionType() {
		$int = $this->m_link->getActionType();
		return $int;
	}

	// Returns the begin of a link in a text.
	function getBegin() {
		$int = $this->m_link->getBegin();
		return $int;
	}

	// Returns the end of a link in a text.
	function getEnd() {
		$int = $this->m_link->getEnd();
		return $int;
	}

	// Returns string which is an external hyperlink or
	// null if type of link is not ExternalHyperlink.
	function getExternalHyperlink() {
		$string = $this->m_link->getExternalHyperlink();
		return $string;
	}

	// Returns Id of a slide for internal hyperlink or
	// -1 if type of link is not InternalHyperlink.
	function getInternalHyperlink() {
		$int = $this->m_link->getInternalHyperlink();
		return $int;
	}

	// Returns jump type for a link if ActionType is JumpAction.
	function getJumpType() {
		$int = $this->m_link->getJumpType();
		return $int;
	}

	// Sets the begin of a link in a text.
	function setBegin($int) {
		$this->m_link->setBegin($int);
	}

	// Sets the end of a link in a text.
	function setEnd($int) {
		$this->m_link->setEnd($int);
	}

	// Sets link destination to the custom url and
	// changes action type to HyperlinkAction.
	function setExternalHyperlink($string) {
		$this->m_link->setExternalHyperlink($string);
	}

	// Sets link destination to a slide inside presentation and
	// changes action type to HyperlinkAction.
	//  function setInternalHyperlink($long) {
	//    $Link->setInternalHyperlink($long);
	//  }

	// Sets link destination to a slide inside presentation and
	// changes action type to HyperlinkAction.
	function setInternalHyperlink($slide_or_long) {
		$this->m_link->setInternalHyperlink($slide_or_long);
	}

	// Sets jump destination and changes action type to JumpAction.
	function setJump($int) {
		$this->m_link->setJump($int);
	}
}

// Represents the collection of a links.
class Links {

	public $m_links;

	function __construct($links) {
		$this->m_links = $links;
	}

	// Adds a new Link to the end of the collection.
	function addLink() {
		$link = $this->m_links->addLink();
		$link_php = new Link($link);
		return $link_php;
	}

	// Removes all elements from the collection.
	function clear() {
		$this->m_links->clear();
	}

	// Gets the element at the specified index.
	function get($int) {
		$link = $this->m_links->get($int);
		$link_php = new Link($link);
		return $link_php;
	}

	// Removes the element at the specified index of the collection.
	function remove($int) {
		$this->m_links->remove($int);
	}

	// Gets the number of elements actually contained in a collection.
	function size() {
		$int = $this->m_links->size();
		return $int;
	}
}

// Represents the main master slide in a presentation.
class MainMaster extends Slide {

	function __construct($slide) {
		parent::__construct($slide);
	}
}

// Represents the notes of a slide.
class Notes {

	public $m_notes;

	function __construct($notes) {
		$this->m_notes = $notes;
	}

	// Returns the list of all paragraphs for a notes.
	function getParagraphs() {
		$paragraphs = $this->m_notes->getParagraphs();
		$paragraphs_php = new Paragraphs($paragraphs);
		return $paragraphs_php;
	}

	// Returns the parent slide.
	function getParent() {
		$slide = $this->m_notes->getParent();
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the plain text for a notes.
	function getText() {
		$string = $this->m_notes->getText();
		return $string;
	}

	// Determines whether the notes follow the notes master background.
	function isFollowMasterBackground() {
		$boolean = $this->m_notes->isFollowMasterBackground();
		return $boolean;
	}

	// Determines whether the notes objects follow the notes master objects style.
	function isFollowMasterObjects() {
		$boolean = $this->m_notes->isFollowMasterObjects();
		return $boolean;
	}

	// Determines whether the notes follow the notes master color scheme.
	function isFollowMasterScheme() {
		$boolean = $this->m_notes->isFollowMasterScheme();
		return $boolean;
	}

	// Sets whether the notes follow the notes master background.
	function setFollowMasterBackground($boolean) {
		$this->m_notes->setFollowMasterBackground($boolean);
	}

	// Sets whether the notes objects follow the notes master objects style.
	function setFollowMasterObjects($boolean) {
		$this->m_notes->setFollowMasterObjects($boolean);
	}

	// Sets whether the notes follow the notes master color scheme.
	function setFollowMasterScheme($boolean) {
		$this->m_notes->setFollowMasterScheme($boolean);
	}
}

// Represents the OleObjectFrame shape.
class OleObjectFrame extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns full path to the linked file.
	function getLinkPathLong() {
		$string = $this->m_shape->getLinkPathLong();
		return $string;
	}

	// Returns full path to the linked file.
	function getLinkPathShort() {
		$string = $this->m_shape->getLinkPathShort();
		return $string;
	}

	// Returns the class name of an object.
	function getObjectClassName() {
		$string = $this->m_shape->getObjectClassName();
		return $string;
	}

	// Returns the embedded object as byte array.
	function getObjectData() {
		$byte = $this->m_shape->getObjectData();
		return $byte;
	}

	// Returns the name of an object.
	function getObjectName() {
		$string = $this->m_shape->getObjectName();
		return $string;
	}

	// Returns the ProgID of an object.
	function getObjectProgId() {
		$string = $this->m_shape->getObjectProgId();
		return $string;
	}

	// Returns the type of an object.
	function getObjectType() {
		$int = $this->m_shape->getObjectType();
		return $int;
	}

	// Determines whether the object is visible as icon only.
	function isObjectIcon() {
		$boolean = $this->m_shape->isObjectIcon();
		return $boolean;
	}

	// Determines whether the object is link and not embedded to a presentation.
	function isObjectLink() {
		$boolean = $this->m_shape->isObjectLink();
		return $boolean;
	}

	// Sets the class name of an object.
	function setObjectClassName($string) {
		$this->m_shape->setObjectClassName($string);
	}

	// Sets embedded object as byte array.
	function setObjectData($byte) {
		$this->m_shape->setObjectData($byte);
	}

	// Sets whether the object is visible as icon only.
	function setObjectIcon($boolean) {
		$this->m_shape->setObjectIcon($boolean);
	}

	// Sets the name of an object.
	function setObjectName($string) {
		$this->m_shape->setObjectName($string);
	}

	// Sets the ProgID of an object.
	function setObjectProgId($string) {
		$this->m_shape->setObjectProgId($string);
	}

	// Returns the brightness (0-100%) of a picture.
	function getBrightness() {
		$int = $this->m_shape->getBrightness();
		return $int;
	}

	// Returns the type of color transformation applied to a picture.
	function getColorType() {
		$int = $this->m_shape->getColorType();
		return $int;
	}

	// Returns the contrast (0-100%) of a picture.
	function getContrast() {
		$int = $this->m_shape->getContrast();
		return $int;
	}

	// Returns the number of percents of real image height that are cropped off the bottom of the picture.
	function getCropBottom() {
		$double = $this->m_shape->getCropBottom();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the left of the picture.
	function getCropLeft() {
		$double = $this->m_shape->getCropLeft();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the right of the picture.
	function getCropRight() {
		$double = $this->m_shape->getCropRight();
		return $double;
	}

	// Returns the number of percents of real image height that are cropped off the top of the picture.
	function getCropTop() {
		$double = $this->m_shape->getCropTop();
		return $double;
	}

	// Returns the picture Id for a PictureFrame.
	function getPictureId() {
		$int = $this->m_shape->getPictureId();
		return $int;
	}

	// Returns the table of colors replacements for recoloring metafiles.
	function getRecolor() {
		$recolorTable = $this->m_shape->getRecolor();
		$recolorTable_php = new RecolorTable($recolorTable);
		return $recolorTable_php;
	}

	// Returns the transparent color of a picture.
	// java.awt.Color
	function getTransparentColor() {
		$color = $this->m_shape->getTransparentColor();
		return $color;
	}

	// Sets the brightness (0-100%) of a picture.
	function setBrightness($int) {
		$this->m_shape->setBrightness($int);
	}

	// Sets the type of color transformation applied to a picture.
	function setColorType($int) {
		$this->m_shape->setColorType($int);
	}

	// Sets the contrast (0-100%) of a picture.
	function setContrast($int) {
		$this->m_shape->setContrast($int);
	}

	// Sets the number of percents of real image height that are cropped off the bottom of the picture.
	function setCropBottom($double) {
		$this->m_shape->setCropBottom($double);
	}

	// Sets the number of percents of real image width that are cropped off the left of the picture.
	function setCropLeft($double) {
		$this->m_shape->setCropLeft($double);
	}

	// Sets the number of percents of real image width that are cropped off the right of the picture.
	function setCropRight($double) {
		$this->m_shape->setCropRight($double);
	}

	// Sets the number of percents of real image height that are cropped off the top of the picture.
	function setCropTop($double) {
		$this->m_shape->setCropTop($double);
	}

	// Sets the picture Id for a PictureFrame.
	function setPictureId($int) {
		$this->m_shape->setPictureId($int);
	}

	// sets the transparent color of a picture.
	function setTransparentColor($Color) {
		$this->m_shape->setTransparentColor($Color);
	}
}

// Represents the paragraph of a text.
class Paragraph {

	public $m_paragraph;

	function __construct($para) {
		$this->m_paragraph = $para;
	}

	// Returns the alignment of a paragraph.
	function getAlignment() {
		$int = $this->m_paragraph->getAlignment();
		return $int;
	}

	// Returns the character that is used for the paragraph's bullet.
	function getBulletCharacter() {
		$char = $this->m_paragraph->getBulletCharacter();
		return $char;
	}

	// Returns the color of the paragraph's bullet.
	// java.awt.Color
	function getBulletColor() {
		$color = $this->m_paragraph->getBulletColor();
		return $color;
	}

	// Returns the font of the paragraph's bullet.
	function getBulletFontIndex() {
		$short = $this->m_paragraph->getBulletFontIndex();
		return $short;
	}

	// Returns the bullet size relatively to the size of the first portion in the paragraph.
	function getBulletHeight() {
		$short = $this->m_paragraph->getBulletHeight();
		return $short;
	}

	// Returns the offset of the paragraph's bullet.
	function getBulletOffset() {
		$short = $this->m_paragraph->getBulletOffset();
		return $short;
	}

	// Returns the type of an bullet.
	function getBulletType() {
		$int = $this->m_paragraph->getBulletType();
		return $int;
	}

	// Returns the depth of a paragraph.
	function getDepth() {
		$short = $this->m_paragraph->getDepth();
		return $short;
	}

	// Determines whether the paragraph has bullet.
	function getHasBullet() {
		$short = $this->m_paragraph->getHasBullet();
		return $short;
	}

	// Returns the beginning value of a numbered bullet.
	function getNumberedBulletStartWith() {
		$short = $this->m_paragraph->getNumberedBulletStartWith();
		return $short;
	}

	// Returns the style of a numbered bullet.
	function getNumberedBulletStyle() {
		$int = $this->m_paragraph->getNumberedBulletStyle();
		return $int;
	}

	// Returns the PictureBullet id.
	function getPictureBulletId() {
		$short = $this->m_paragraph->getPictureBulletId();
		return $short;
	}

	// Returns the collection of a text portions.
	function getPortions() {
		$portions = $this->m_paragraph->getPortions();
		$portions_php = new Portions($portions);
		return $portions_php;
	}

	// Returns the alignment of a paragraph.
	function getRawAlignment() {
		$int = $this->m_paragraph->getRawAlignment();
		return $int;
	}

	// Returns the character that is used for bullets in the specified text.
	function getRawBulletCharacter() {
		$int = $this->m_paragraph->getRawBulletCharacter();
		return $int;
	}

	// Returns the color of a bullet.
	function getRawBulletColor() {
		$color = $this->m_paragraph->getRawBulletColor();
		return $color;
	}

	// Returns the font of the bullet.
	function getRawBulletFontIndex() {
		$short = $this->m_paragraph->getRawBulletFontIndex();
		return $short;
	}

	// Returns the bullet size relative to the size of
	// the first portion in a paragraph.
	function getRawBulletHeight() {
		$short = $this->m_paragraph->getRawBulletHeight();
		return $short;
	}

	// Returns the offset of the bullet.
	function getRawBulletOffset() {
		$short = $this->m_paragraph->getRawBulletOffset();
		return $short;
	}

	// Returns raw value of a bullet:
	// (-1) - value should be inherited from the master.
	function getRawHasBullet() {
		$short = $this->m_paragraph->getRawHasBullet();
		return $short;
	}

	// Returns raw color of a bullet:
	// (-1) - value should be inherited from the master.
	function getRawIsBulletHardColor() {
		$short = $this->m_paragraph->getRawIsBulletHardColor();
		return $short;
	}

	// Returns raw font of a bullet:
	// (-1) - value should be inherited from the master.
	function getRawIsBulletHardFont() {
		$short = $this->m_paragraph->getRawIsBulletHardFont();
		return $short;
	}

	// Returns the beginning value of a numbered bullet.
	function getRawNumberedBulletStartWith() {
		$short = $this->m_paragraph->getRawNumberedBulletStartWith();
		return $short;
	}

	// Returns the style of a numbered bullet.
	function getRawNumberedBulletStyle() {
		$int = $this->m_paragraph->getRawNumberedBulletStyle();
		return $int;
	}

	// Returns the PictureBullet Id.
	function getRawPictureBulletId() {
		$short = $this->m_paragraph->getRawPictureBulletId();
		return $short;
	}

	function getRawSpaceAfter() {
		$short = $this->m_paragraph->getRawSpaceAfter();
		return $short;
	}

	function getRawSpaceBefore() {
		$short = $this->m_paragraph->getRawSpaceBefore();
		return $short;
	}

	function getRawSpaceWithin() {
		$short = $this->m_paragraph->getRawSpaceWithin();
		return $short;
	}

	function getRawTextOffset() {
		$short = $this->m_paragraph->getRawTextOffset();
		return $short;
	}

	// Returns the amount of space after the last line in the paragraph, in percents of line.
	function getSpaceAfter() {
		$short = $this->m_paragraph->getSpaceAfter();
		return $short;
	}

	// Returns the amount of space before the first line in the paragraph, in percents of line.
	function getSpaceBefore() {
		$short = $this->m_paragraph->getSpaceBefore();
		return $short;
	}

	// Returns the amount of space between base lines in the paragraph, in percents of line.
	function getSpaceWithin() {
		$short = $this->m_paragraph->getSpaceWithin();
		return $short;
	}

	// Returns the plain text of the whole paragraph.
	function getText() {
		$string = $this->m_paragraph->getText();
		return $string;
	}

	// Returns the offset of the paragraph's text.
	function getTextOffset() {
		$short = $this->m_paragraph->getTextOffset();
		return $short;
	}

	// Determines whether the bullet uses own font.
	function isBulletHardFont() {
		$boolean = $this->m_paragraph->isBulletHardFont();
		return $boolean;
	}

	// Determines whether the paragraph has extended bullets (numbered or with images).
	function isExtendedBullet() {
		$boolean = $this->m_paragraph->isExtendedBullet();
		return $boolean;
	}

	// Sets the alignment of a paragraph.
	function setAlignment($int) {
		$this->m_paragraph->setAlignment($int);
	}

	// Sets the character that is used for the paragraph's bullet.
	function setBulletCharacter($char) {
		$this->m_paragraph->setBulletCharacter($char);
	}

	// Sets the color of the paragraph's bullet.
	// java.awt.Color
	function setBulletColor($color) {
		$this->m_paragraph->setBulletColor($color);
	}

	// Sets the font of the paragraph's bullet.
	function setBulletFontIndex($short) {
		$this->m_paragraph->setBulletFontIndex($short);
	}

	// Sets whether the bullet uses own font.
	function setBulletHardFont($boolean) {
		$this->m_paragraph->setBulletHardFont($boolean);
	}

	// Sets the bullet size relatively to the size of the first portion in the paragraph.
	function setBulletHeight($short) {
		$this->m_paragraph->setBulletHeight($short);
	}

	// Sets the offset of the paragraph's bullet.
	function setBulletOffset($short) {
		$this->m_paragraph->setBulletOffset($short);
	}

	// Sets the depth of a paragraph.
	function setDepth($short) {
		$this->m_paragraph->setDepth($short);
	}

	// Sets whether the paragraph has bullet.
	function setHasBullet($short) {
		$this->m_paragraph->setHasBullet($short);
	}

	// Sets the beginning value of a numbered bullet.
	function setNumberedBulletStartWith($short) {
		$this->m_paragraph->setNumberedBulletStartWith($short);
	}

	// Sets the style of a numbered bullet.
	function setNumberedBulletStyle($int) {
		$this->m_paragraph->setNumberedBulletStyle($int);
	}

	// Sets the PictureBullet id.
	function setPictureBulletId($short) {
		$this->m_paragraph->setPictureBulletId($short);
	}

	function setRawAlignment($int) {
		$this->m_paragraph->setRawAlignment($int);
	}

	function setRawBulletCharacter($char) {
		$this->m_paragraph->setRawBulletCharacter($char);
	}

	function setRawBulletColor($color) {
		$this->m_paragraph->setRawBulletColor($color);
	}

	function setRawBulletFontIndex($short) {
		$this->m_paragraph->setRawBulletFontIndex($short);
	}

	function setRawBulletHeight($short) {
		$this->m_paragraph->setRawBulletHeight($short);
	}

	function setRawBulletOffset($short) {
		$this->m_paragraph->setRawBulletOffset($short);
	}

	function setRawHasBullet($short) {
		$this->m_paragraph->setRawHasBullet($short);
	}

	function setRawIsBulletHardColor($short) {
		$this->m_paragraph->setRawIsBulletHardColor($short);
	}

	function setRawIsBulletHardFont($short) {
		$this->m_paragraph->setRawIsBulletHardFont($short);
	}

	function setRawNumberedBulletStartWith($short) {
		$this->m_paragraph->setRawNumberedBulletStartWith($short);
	}

	function setRawNumberedBulletStyle($int) {
		$this->m_paragraph->setRawNumberedBulletStyle($int);
	}

	function setRawPictureBulletId($short) {
		$this->m_paragraph->setRawPictureBulletId($short);
	}

	function setRawSpaceAfter($short) {
		$this->m_paragraph->setRawSpaceAfter($short);
	}

	function setRawSpaceBefore($short) {
		$this->m_paragraph->setRawSpaceBefore($short);
	}

	function setRawSpaceWithin($short) {
		$this->m_paragraph->setRawSpaceWithin($short);
	}

	function setRawTextOffset($short) {
		$this->m_paragraph->setRawTextOffset($short);
	}

	// Sets the amount of space after the last line in the paragraph, in percents of line.
	function setSpaceAfter($short) {
		$this->m_paragraph->setSpaceAfter($short);
	}

	// Sets the amount of space before the first line in the paragraph, in percents of line.
	function setSpaceBefore($short) {
		$this->m_paragraph->setSpaceBefore($short);
	}

	// Sets the amount of space between base lines in the paragraph, in percents of line.
	function setSpaceWithin($short) {
		$this->m_paragraph->setSpaceWithin($short);
	}

	// Sets the plain text of the whole paragraph.
	function setText($string) {
		$this->m_paragraph->setText($string);
	}

	// Sets the offset of the paragraph's text.
	function setTextOffset($short) {
		$this->m_paragraph->setTextOffset($short);
	}
}

// Represents the collection of a paragraphs.
class Paragraphs {

	public $m_paragraphs;

	function __construct($paras) {
		$this->m_paragraphs = $paras;
	}

	// Adds the paragraph into the collection at the specified index.
	function insert($int, $paragraph_php) {
		$this->m_paragraphs->add($int, $paragraph_php->m_paragraph);
	}

	// Adds the paragraph to the end of this collection.
	function add($paragraph_php) {
		$int = $this->m_paragraphs->add($paragraph_php->m_paragraph);
		return $int;
	}

	// Removes all elements from the collection.
	function clear() {
		$this->m_paragraphs->clear();
	}

	// Returns the element at the specified index.
	function get($int) {
		$paragraph = $this->m->paragraphs->get($int);
		$paragraph_php = new Paragraph($paragraph);
		return $paragraph_php;
	}

	// Generates string array with text strings for text-based bullets.
	function getBulletsText() {
		$string = $this->m_paragraphs->getBulletsText();
		return $string;
	}

	// Generates and returns integer array with numbers for numbered lists.
	function getNumberedBulletsNumbers() {
		$int = $this->m_paragraphs->getNumberedBulletsNumbers();
		return $int;
	}

	// Removes the element at the specified index from the collection.
	function remove($int) {
		$this->m_paragraphs->remove($int);
	}

	// Returns the number of elements in this collection.
	function size() {
		$int = $this->m_paragraphs->size();
		return $int;
	}
}

// Represents the picture in a presentation.
class Picture extends PPImage {

	function __construct($ppimage) {
		parent::__construct($ppimage);
	}

	// Returns the unique Id of a picture.
	function getPictureId() {
		$int = $this->m_image->getPictureId();
		return $int;
	}
}

// Represents the picture of an extended bullet in a presentation.
class PictureBullet extends PPImage {

	function __construct($ppimage) {
		parent::__construct($ppimage);
	}
}

// Represents the collection of PictureBullets in a presentation.
class PictureBullets {

	public $m_pictureBullets;

	function __construct($picture) {
		$this->m_pictureBullets = $picture;
	}

	// Adds a PictureBullet to the end of a collection.
	function add($pictureBullet_php) {
		$short = $this->m_pictureBullets->add($pictureBullet_php->m_image);
		return $short;
	}

	// Gets the element at the specified index.
	function get($int) {
		$pictureBullet = $this->m_pictureBullets->get($int);
		$pictureBullet_php = PictureBullet($pictureBullet);
		return $pictureBullet_php;
	}

	// Returns an iterator for the entire collection.
	// java.util.Iterator
	function iterator() {
		$iter = $this->m_pictureBullets->iterator();
		return $iter;
	}

	// Returns the number of elements in the collection.
	function size() {
		$int = $this->m_pictureBullets->size();
		return $int;
	}
}

// Represents the PictureFrame shape.
class PictureFrame extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns the brightness (0-100%) of a picture.
	function getBrightness() {
		$int = $this->m_shape->getBrightness();
		return $int;
	}

	// Returns the type of color transformation applied to a picture.
	function getColorType() {
		$int = $this->m_shape->getColorType();
		return $int;
	}

	// Returns the contrast (0-100%) of a picture.
	function getContrast() {
		$int = $this->m_shape->getContrast();
		return $int;
	}

	// Returns the number of percents of real image height that are cropped off the bottom of the picture.
	function getCropBottom() {
		$double = $this->m_shape->getCropBottom();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the left of the picture.
	function getCropLeft() {
		$double = $this->m_shape->getCropLeft();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the right of the picture.
	function getCropRight() {
		$double = $this->m_shape->getCropRight();
		return $double;
	}

	// Returns the number of percents of real image height that are cropped off the top of the picture.
	function getCropTop() {
		$double = $this->m_shape->getCropTop();
		return $double;
	}

	// Returns the picture Id for a PictureFrame.
	function getPictureId() {
		$int = $this->m_shape->getPictureId();
		return $int;
	}

	// Returns the table of colors replacements for recoloring metafiles.
	function getRecolor() {
		$recolorTable = $this->m_shape->getRecolor();
		$recolorTable_php = new RecolorTable($recolorTable);
		return $recolorTable_php;
	}

	// Returns the transparent color of a picture.
	// java.awt.Color
	function getTransparentColor() {
		$color = $this->m_shape->getTransparentColor();
		return $color;
	}

	// Sets the brightness (0-100%) of a picture.
	function setBrightness($int) {
		$this->m_shape->setBrightness($int);
	}

	// Sets the type of color transformation applied to a picture.
	function setColorType($int) {
		$this->m_shape->setColorType($int);
	}

	// Sets the contrast (0-100%) of a picture.
	function setContrast($int) {
		$this->m_shape->setContrast($int);
	}

	// Sets the number of percents of real image height that are cropped off the bottom of the picture.
	function setCropBottom($double) {
		$this->m_shape->setCropBottom($double);
	}

	// Sets the number of percents of real image width that are cropped off the left of the picture.
	function setCropLeft($double) {
		$this->m_shape->setCropLeft($double);
	}

	// Sets the number of percents of real image width that are cropped off the right of the picture.
	function setCropRight($double) {
		$this->m_shape->setCropRight($double);
	}

	// Sets the number of percents of real image height that are cropped off the top of the picture.
	function setCropTop($double) {
		$this->m_shape->setCropTop($double);
	}

	// Sets the picture Id for a PictureFrame.
	function setPictureId($int) {
		$this->m_shape->setPictureId($int);
	}

	// sets the transparent color of a picture.
	function setTransparentColor($Color) {
		$this->m_shape->setTransparentColor($Color);
	}
}

// Represents the collection of a Pictures.
class Pictures {

	public $m_pictures;

	function __construct($pictures) {
		$this->m_pictures = $pictures;
	}

	// Adds the picture at the end of this collection.
	function add($picture_php) {
		$int = $this->m_pictures->add($picture_php->m_image);
		return $int;
	}

	// Returns the element at the specified index.
	function get($int) {
		$picture = $this->m_pictures->get($int);
		$picture_php = new Picture($picture);
		return $picture_php;
	}

	// Returns the Picture by its Id.
	function getPictureById($int) {
		$picture = $this->m_pictures->getPictureById($int);
		$picture_php = new Picture($picture);
		return $picture_php;
	}

	// Returns the number of elements in this collection.
	function size() {
		$int = $this->m_pictures->size();
		return $int;
	}
}

// Represents the placeholder on a slide.
class Placeholder {

	public $m_placeholder;

	function __construct($pholder) {
		$this->m_placeholder = $pholder;
	}

	// Returns the height of the placeholder.
	function getHeight() {
		$int = $this->m_placeholder->getHeight();
		return $int;
	}

	// Returns the parent slide.
	function getParent() {
		$slide = $this->m_placeholder->getParent();
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the type of a placeholder.
	function getPlaceholderType() {
		$int = $this->m_placeholder->getPlaceholderType();
		return $int;
	}

	// Returns the width of the placeholder.
	function getWidth() {
		$int = $this->m_placeholder->getWidth();
		return $int;
	}

	// Returns the x-coordinate of the upper-left corner of the placeholder.
	function getX() {
		$int = $this->m_placeholder->getX();
		return $int;
	}

	// Returns the y-coordinate of the upper-left corner of the placeholder.
	function getY() {
		$int = $this->m_placeholder->getY();
		return $int;
	}

	// Do nothing for unknown placeholders.
	function setHeight($int) {
		$this->m_placeholder->setHeight($int);
	}

	// Do nothing for unknown placeholders.
	function setWidth($int) {
		$this->m_placeholder->setWidth($int);
	}

	// Do nothing for unknown placeholders.
	function setX($int) {
		$this->m_placeholder->setX($int);
	}

	// Do nothing for unknown placeholders.
	function setY($int) {
		$this->m_placeholder->setY($int);
	}
}

// Represents the collection of a placeholders.
class Placeholders {

	public $m_placeholders;

	function __construct($pholders) {
		$this->m_placeholders = $pholders;
	}

	// Returns the element at the specified index.
	function get($int) {
		$placeholder = $this->m_placeholders->get($int);
		$cf = new ClassFactory();
		$placeholder_php = $cf->CreatePlaceholderPhp($placeholder);
		return $placeholder_php;
	}

	// Returns the number of elements in this collection.
	function size() {
		$int = $this->m_placeholders->size();
		return $int;
	}
}

// Represents the Polyline shape.
class Polyline extends Shape {

	function __construct($shape) {
		parent :: __construct($shape);
	}

	// Returns the list of a points for the polyline.
	function getPoints() {
		$point = $this->m_shape->getPoints();
		return $point;
	}

	// Returns the list of a segments for the polyline.
	function getSegments() {
		$int = $this->m_shape->getSegments();
		return $int;
	}
}

// Represents the portion of a text paragraph.
class Portion {

	public $m_portion;

	function __construct($portion) {
		$this->m_portion = $portion;
	}

	// Returns the index of the font used for east asian and complex text in a Fonts collection.
	function getAsianOrComplexFontIndex() {
		$short = $this->m_portion->getAsianOrComplexFontIndex();
		return $short;
	}

	// Returns superscript or subscript text.
	function getEscapement() {
		$short = $this->m_portion->getEscapement();
		return $short;
	}

	// Returns the color of a portion.
	// java.awt.Color
	function getFontColor() {
		$color = $this->m_portion->getFontColor();
		return $color;
	}

	// Returns index of color in color scheme or (-1) for scheme-independed color.
	function getFontColorIndex() {
		$short = $this->m_portion->getFontColorIndex();
		return $short;
	}

	// Returns the font height of a portion.
	function getFontHeight() {
		$short = $this->m_portion->getFontHeight();
		return $short;
	}

	// Returns the index of the used font in a Fonts collection.
	function getFontIndex() {
		$short = $this->m_portion->getFontIndex();
		return $short;
	}

	function getRawAsianOrComplexFontIndex() {
		$short = $this->m_portion->getRawAsianOrComplexFontIndex();
		return $short;
	}

	function getRawEscapement() {
		$short = $this->m_portion->getRawEscapement();
		return $short;
	}

	function getRawFontColor() {
		$color = $this->m_portion->getRawFontColor();
		return $color;
	}

	function getRawFontEmbossed() {
		$short = $this->m_portion->getRawFontEmbossed();
		return $short;
	}

	function getRawFontHeight() {
		$short = $this->m_portion->getRawFontHeight();
		return $short;
	}

	function getRawFontIndex() {
		$short = $this->m_portion->getRawFontIndex();
		return $short;
	}

	function getRawFontShadow() {
		$short = $this->m_portion->getRawFontShadow();
		return $short;
	}

	function getRawFontUnderline() {
		$short = $this->m_portion->getRawFontUnderline();
		return $short;
	}

	function getRawSymbolFontIndex() {
		$short = $this->m_portion->getRawSymbolFontIndex();
		return $short;
	}

	// Returns the index of the font used for special symbols in a Fonts collection.
	function getSymbolFontIndex() {
		$short = $this->m_portion->getSymbolFontIndex();
		return $short;
	}

	// Returns the plain text of a portion.
	function getText() {
		$string = $this->m_portion->getText();
		return $string;
	}

	// Determines whether the font is bold.
	function isFontBold() {
		$boolean = $this->m_portion->isFontBold();
		return $boolean;
	}

	// Determines whether the font is embossed.
	function isFontEmbossed() {
		$boolean = $this->m_portion->isFontEmbossed();
		return $boolean;
	}

	// Determines whether the font is italic
	function isFontItalic() {
		$boolean = $this->m_portion->isFontItalic();
		return $boolean;
	}

	// Determines whether the font has shadow.
	function isFontShadow() {
		$boolean = $this->m_portion->isFontShadow();
		return $boolean;
	}

	// Determines whether the font is underlined.
	function isFontUnderline() {
		$boolean = $this->m_portion->isFontUnderline();
		return $boolean;
	}

	function isRawFontBold() {
		$boolean = $this->m_portion->isRawFontBold();
		return $boolean;
	}

	function isRawFontItalic() {
		$boolean = $this->m_portion->isRawFontItalic();
		return $boolean;
	}

	// Sets the index of the font used for east asian and complex text in a Fonts collection.
	function setAsianOrComplexFontIndex($short) {
		$this->m_portion->setAsianOrComplexFontIndex($short);
	}

	// Sets superscript or subscript text.
	function setEscapement($short) {
		$this->m_portion->setEscapement($short);
	}

	// Sets whether the font is bold.
	function setFontBold($boolean) {
		$this->m_portion->setFontBold($boolean);
	}

	// Sets the color of a portion.
	function setFontColor($color) {
		$this->m_portion->setFontColor($color);
	}

	// Sets index of color in color scheme or (-1) for scheme-independed color.
	function setFontColorIndex($short) {
		$this->m_portion->setFontColorIndex($short);
	}

	// Sets whether the font is embossed.
	function setFontEmbossed($boolean) {
		$this->m_portion->setFontEmbossed($boolean);
	}

	// Sets the font height of a portion.
	function setFontHeight($short) {
		$this->m_portion->setFontHeight($short);
	}

	// Sets the index of the used font in a Fonts collection.
	function setFontIndex($short) {
		$this->m_portion->setFontIndex($short);
	}

	// Sets whether the font is italic.
	function setFontItalic($boolean) {
		$this->m_portion->setFontItalic($boolean);
	}

	// Sets whether the font has shadow.
	function setFontShadow($boolean) {
		$this->m_portion->setFontShadow($boolean);
	}

	// Sets whether the font is underlined.
	function setFontUnderline($boolean) {
		$this->m_portion->setFontUnderline($boolean);
	}

	function setRawAsianOrComplexFontIndex($short) {
		$this->m_portion->setRawAsianOrComplexFontIndex($short);
	}

	function setRawEscapement($short) {
		$this->m_portion->setRawEscapement($short);
	}

	function setRawFontBold($boolean) {
		$this->m_portion->setRawFontBold($boolean);
	}

	function setRawFontColor($color) {
		$this->m_portion->setRawFontColor($color);
	}

	function setRawFontEmbossed($short) {
		$this->m_portion->setRawFontEmbossed($short);
	}

	function setRawFontHeight($short) {
		$this->m_portion->setRawFontHeight($short);
	}

	function setRawFontIndex($short) {
		$this->m_portion->setRawFontIndex($short);
	}

	function setRawFontItalic($boolean) {
		$this->m_portion->setRawFontItalic($boolean);
	}

	function setRawFontShadow($short) {
		$this->m_portion->setRawFontShadow($short);
	}

	function setRawFontUnderline($short) {
		$this->m_portion->setRawFontUnderline($short);
	}

	function setRawSymbolFontIndex($short) {
		$this->m_portion->setRawSymbolFontIndex($short);
	}

	// Sets the index of the font used for special symbols in a Fonts collection.
	function setSymbolFontIndex($short) {
		$this->m_portion->setSymbolFontIndex($short);
	}

	// Sets the plain text of a portion.
	function setText($string) {
		$this->m_portion->setText($string);
	}
}

// Represents the collection of a portions.
class Portions {

	public $m_portions;

	function __construct($portions) {
		$this->m_portions = $portions;
	}

	// Adds the portion into the collection at the specified index.
	function insert($int, $portion) {
		$this->m_portions->add($int, $portion->m_portion);
	}

	// Adds the portion at the end of the collection.
	function add($portion) {
		$int = $this->m_portions->add($portion->m_portion);
		return $int;
	}

	// Removes all elements from the collection.
	function clear() {
		$this->m_portions->clear();
	}

	// Returns the element at the specified index.
	function get($int) {
		$portion = $this->m_portions->get($int);
		$portion_php = new Portion($portion);
		return $portion_php;
	}

	// Removes the element at the specified index.
	function remove($int) {
		$this->m_portions->remove($int);
	}

	// Returns the number of elements in this collection.
	function size() {
		$int = $this->m_portions->size();
		return $int;
	}
}

// Represents an abstract image used in a presentation.
class PPImage {

	public $m_image;

	function __construct($ppimage) {
		$this->m_image = $ppimage;
	}

	// Returns an Image object.
	function getImage() {
		$byte = $this->m_image->getImage();
		return $byte;
	}

	// Returns the format of a picture.
	function getImageFormat() {
		$int = $this->m_image->getImageFormat();
		return $int;
	}

	// Returns the parent presentation for a picture.
	function getParent() {
		$presentation = $this->m_image->getParent();
		$presentation_php = new Presentation($presentation);
		return $presentation_php;
	}

	// Returns a RenderedImage object.
	// java.awt.image.RenderedImage
	function getRenderedImage() {
		$renderedImage = $this->m_image->getRenderedImage();
		return $renderedImage;
	}

	// Writes picture to a stream.
	// file name or java.io.FileOutputStream
	function write($output) {
		if (is_string($output)) {
			$output_file = new Java('java.io.File', $output);
			$output_stream = new Java('java.io.FileOutputStream', $output_file);
			$this->m_image->write($output_stream);
			$output_stream->flush();
			$output_stream->close();
		} else {
			$this->m_image->write($output);
		}
	}
}

// Represents the Microsoft PowerPoint presentation.
class Presentation {

	public $m_presentation;

	function __construct($pres) {
		$this->m_presentation = $pres;
	}

	// Adds the new Slide with header and body placeholders to a presentation.
	function addBodySlide() {
		$slide = $this->m_presentation->addBodySlide();
		$slide_php = new Slide($slide);
		return $slide_php;
	}

	// Adds the new Slide with header and two body placeholders to a presentation.
	function addDoubleBodySlide() {
		$slide = $this->m_presentation->addDoubleBodySlide();
		$slide_php = new Slide($slide);
		return $slide_php;
	}

	// Adds the new empty Slide to a presentation.
	function addEmptySlide() {
		$slide = $this->m_presentation->addEmptySlide();
		$slide_php = new Slide($slide);
		return $slide_php;
	}

	// Adds the new Slide with header placeholder to a presentation.
	function addHeaderSlide() {
		$slide = $this->m_presentation->addHeaderSlide();
		$slide_php = new Slide($slide);
		return $slide_php;
	}

	// Adds the new Slide with header and subheader placeholders to a presentation.
	function addTitleSlide() {
		$slide = $this->m_presentation->addTitleSlide();
		$slide_php = new Slide($slide);
		return $slide_php;
	}

	// Makes a copy of a slide with master slides and inserts it to another presentation.
	function cloneSlide($srcSlide, $position, $pres = null) {
		$slide = null;
		if ($pres == null) {
			$slide = $this->m_presentation->cloneSlide($srcSlide, $position);
		} else {
			$slide = $this->m_presentation->cloneSlide($srcSlide, $position, $pres, null);
		}
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Deletes all unused masters from a presentation.
	function deleteUnusedMasters() {
		$this->m_presentation->deleteUnusedMasters();
	}

	// Returns the Id of the active slide in a presentation.
	function getActiveSlideId() {
		$long = $this->m_presentation->getActiveSlideId();
		return $long;
	}

	// Returns the author of a presentation.
	function getAuthor() {
		$string = $this->m_presentation->getAuthor();
		return $string;
	}

	// Returns the comments of a presentation.
	function getComments() {
		$string = $this->m_presentation->getComments();
		return $string;
	}

	// Company where presentation was created.
	function getCompany() {
		$string = $this->m_presentation->getCompany();
		return $string;
	}

	// Returns the time when presentation was created.
	function getCreateTime() {
		$date = $this->m_presentation->getCreateTime();
		return $date;
	}

	// Returns the custom properties of a presentation.
	function getCustomDocumentProperties() {
		$documentProperties = $this->m_presentation->getCustomDocumentProperties();
		$documentProperties_php = new DocumentProperties($documentProperties);
		return $documentProperties_php;
	}

	// Returns the edit time of a presentation.
	function getEditTime() {
		$date = $this->m_presentation->getEditTime();
		return $date;
	}

	// Returns the number of the first slide in a presentation.
	function getFirstSlideNumber() {
		$short = $this->m_presentation->getFirstSlideNumber();
		return $short;
	}

	// Returns the list of all fonts in a presentation.
	function getFonts() {
		$fonts = $this->m_presentation->getFonts();
		$fonts_php = new Fonts($fonts);
		return $fonts_php;
	}

	// Returns the keywords of a presentation.
	function getKeywords() {
		$string = $this->m_presentation->getKeywords();
		return $string;
	}

	// Returns the last author of a presentation.
	function getLastAuthor() {
		$string = $this->m_presentation->getLastAuthor();
		return $string;
	}

	// Returns the last time when presentation was printed.
	function getLastPrintTime() {
		$date = $this->m_presentation->getLastPrintTime();
		return $date;
	}

	// Returns the last time when presentation was saved.
	function getLastSaveTime() {
		$date = $this->m_presentation->getLastSaveTime();
		return $date;
	}

	// Returns the first main master of a presentation.
	function getMainMaster() {
		$mainMaster = $this->m_presentation->getMainMaster();
		$mainMaster_php = new MainMaster($mainMaster);
		return $mainMaster_php;
	}

	// Returns the manager of a presentation.
	function getManager() {
		$string = $this->m_presentation->getManager();
		return $string;
	}

	// Returns the list of all masters in a presentation.
	function getMasters() {
		$slides = $this->m_presentation->getMasters();
		$slides_php = new Slides($slides);
		return $slides_php;
	}

	// Returns the size of a notes in a presentation.
	function getNotesSize() {
		$point = $this->m_presentation->getNotesSize();
		return $point;
	}

	// Returns a list of all pictures used for a bullets that are defined in the presentation.
	function getPictureBullets() {
		$pictureBullets = $this->m_presentation->getPictureBullets();
		$pictureBullets_php = new PictureBullets($pictureBullets);
		return $pictureBullets_php;
	}

	// Returns the list of all pictures in a presentation.
	function getPictures() {
		$pictures = $this->m_presentation->getPictures();
		$pictures_php = new Pictures($pictures);
		return $pictures_php;
	}

	// Returns the slide by Id.
	function getSlideById($long) {
		$slide = $this->m_presentation->getSlideById($long);
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the slide by SlidePosition.
	function getSlideByPosition($int) {
		$slide = $this->m_presentation->getSlideByPosition($int);
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the list of all slides in a presentation.
	function getSlides() {
		$slides = $this->m_presentation->getSlides();
		$slides_php = new Slides($slides);
		return $slides_php;
	}

	// Returns the settings of a slide show in a presentation.
	function getSlideShowSettings() {
		$slideShowSettings = $this->m_presentation->getSlideShowSettings();
		$slideShowSettings_php = new SlideShowSettings($slideShowSettings);
		return $slideShowSettings_php;
	}

	// Returns the size of a slides in a presentation.
	function getSlideSize() {
		$point = $this->m_presentation->getSlideSize();
		return $point;
	}

	// Returns the size type of a slides in a presentation.
	function getSlideSizeType() {
		$int = $this->m_presentation->getSlideSizeType();
		return $int;
	}

	// Returns the subject of a presentation.
	function getSubject() {
		$string = $this->m_presentation->getSubject();
		return $string;
	}

	// Returns the title of a presentation.
	function getTitle() {
		$string = $this->m_presentation->getTitle();
		return $string;
	}

	// Sets the Id of the active slide in a presentation.
	function setActiveSlideId($long) {
		$this->m_presentation->setActiveSlideId($long);
	}

	// Sets the author of a presentation.
	function setAuthor($string) {
		$this->m_presentation->setAuthor($string);
	}

	// Sets the comments of a presentation.
	function setComments($string) {
		$this->m_presentation->setComments($string);
	}

	// Sets the company of a presentation.
	function setCompany($string) {
		$this->m_presentation->setCompany($string);
	}

	// Sets the time when presentation was created.
	function setCreateTime($date) {
		$this->m_presentation->setCreateTime($date);
	}

	// Sets the edit time of a presentation.
	function setEditTime($date) {
		$this->m_presentation->setEditTime($date);
	}

	// Sets the number of the first slide in a presentation.
	function setFirstSlideNumber($short) {
		$this->m_presentation->setFirstSlideNumber($short);
	}

	// Sets the keywords of a presentation.
	function setKeywords($string) {
		$this->m_presentation->setKeywords($string);
	}

	// Sets the last author of a presentation.
	function setLastAuthor($string) {
		$this->m_presentation->setLastAuthor($string);
	}

	// Sets the last time when presentation was printed.
	function setLastPrintTime($date) {
		$this->m_presentation->setLastPrintTime($date);
	}

	// Sets the last time when presentation was saved.
	function setLastSaveTime($date) {
		$this->m_presentation->setLastSaveTime($date);
	}

	// Sets the manager of a presentation.
	function setManager($string) {
		$this->m_presentation->setManager($string);
	}

	// Sets the size of a slides in a presentation.
	function setSlideSize($point) {
		$this->m_presentation->setSlideSize($point);
	}

	// Sets the SizeType of a slides in a presentation.
	function setSlideSizeType($int) {
		$this->m_presentation->setSlideSizeType($int);
	}

	// Sets the subject of a presentation.
	function setSubject($string) {
		$this->m_presentation->setSubject($string);
	}

	// Sets the title of a presentation.
	function setTitle($string) {
		$this->m_presentation->setTitle($string);
	}

	// Writes the contents of the Presentation to an output stream.
	function write($output) {
		if (is_string($output)) {
			$output_file = new Java('java.io.File', $output);
			$output_stream = new Java('java.io.FileOutputStream', $output_file);
			$this->m_presentation->write($output_stream);
			$output_stream->flush();
			$output_stream->close();
		} else {
			$this->m_presentation->write($output);
		}
	}
}

// Represents the recolor table for a picture frames with metafile.
class RecolorTable {

	public $m_recolorTable;

	function __construct($recolor) {
		$this->m_recolorTable = $recolor;
	}

	// Returns the hashtable with fill colors.
	function getFillColors() {
		$hashMap = $this->m_recolorTable->getFillColors();
		return $hashMap;
	}

	// Returns the hashtable with global colors.
	function getGlobalColors() {
		$hashMap = $this->m_recolorTable->getGlobalColors();
		return $hashMap;
	}
}

// Represents the Rectangle shape.
class Rectangle extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// True if rectangle is a master text holder on master slide.
	function isMasterTextHolder() {
		$boolean = $this->m_shape->isMasterTextHolder();
		return $boolean;
	}
}

// Represents the abstract shape on a slide.
class Shape {

	public $m_shape;

	function __construct($shape) {
		$this->m_shape = $shape;
	}

	// Adds the new link to a shape.
	function addLink() {
		$link = $this->m_shape->addLink();
		$link_php = new Link($link);
		return $link_php;
	}

	// Adds a new TextFrame to a shape.
	function addTextFrame($string) {
		$this->m_shape->addTextFrame($string);
	}

	// Clears the Link.
	function clearLink() {
		$this->m_shape->clearLink();
	}

	// Returns the alternative text associated with a shape in a Web presentation.
	function getAlternativeText() {
		$string = $this->m_shape->getAlternativeText();
		return $string;
	}

	// Returns the AnimationSettings object that contains animation properties for a shape.
	function getAnimationSettings() {
		$animSettings = $this->m_shape->getAnimationSettings();
		$animSettings_php = new AnimationSettings($animSettings);
		return $animSettings_php;
	}

	// Returns the FillFormat object that contains fill formatting properties for a shape.
	function getFillFormat() {
		$fillFormat = $this->m_shape->getFillFormat();
		$fillFormat_php = new FillFormat($fillFormat);
		return $fillFormat_php;
	}

	// Returns the height of a shape.
	function getHeight() {
		$int = $this->m_shape->getHeight();
		return $int;
	}

	// Returns the LineFormat object that contains line formatting properties for a shape.
	function getLineFormat() {
		$lineFormat = $this->m_shape->getLineFormat();
		$lineFormat_php = new LineFormat($lineFormat);
		return $lineFormat_php;
	}

	// Return the Link object for a shape.
	function getLink() {
		$link = $this->m_shape->getLink();
		$link_php = new Link($link);
		return $link_php;
	}

	// Returns the name of a shape.
	function getName() {
		$string = $this->m_shape->getName();
		return $string;
	}

	// Returns the parent slide.
	function getParent() {
		$slide = $this->m_shape->getParent();
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the number of degrees the specified shape is rotated around the z-axis.
	function getRotation() {
		$int = $this->m_shape->getRotation();
		return $int;
	}

	// Returns the tags for a shape.
	function getTags() {
		$tags = $this->m_shape->getTags();
		$tags_php = new Tags($tags);
		return $tags_php;
	}

	// Returns the TextFrame object for a Shape.
	function getTextFrame() {
		$textFrame = $this->m_shape->getTextFrame();
		$textFrame_php = new TextFrame($textFrame);
		return $textFrame_php;
	}

	// Returns the width of a shape.
	function getWidth() {
		$int = $this->m_shape->getWidth();
		return $int;
	}

	// Returns the x-coordinate of the upper-left corner of a shape.
	function getX() {
		$int = $this->m_shape->getX();
		return $int;
	}

	// Returns the y-coordinate of the upper-left corner of a shape.
	function getY() {
		$int = $this->m_shape->getY();
		return $int;
	}

	// Returns the position of a shape in the z-order.
	function getZOrderPosition() {
		$int = $this->m_shape->getZOrderPosition();
		return $int;
	}

	// Determines whether the shape is flipped horizontally.
	function isFlipH() {
		$boolean = $this->m_shape->isFlipH();
		return $boolean;
	}

	// Determines whether the shape is flipped vertically.
	function isFlipV() {
		$boolean = $this->m_shape->isFlipV();
		return $boolean;
	}

	// Returns true if shape is a TextHolder.
	function isTextHolder() {
		$boolean = $this->m_shape->isTextHolder();
		return $boolean;
	}

	// Sets the alternative text associated with a shape in a Web presentation.
	function setAlternativeText($string) {
		$this->m_shape->setAlternativeText($string);
	}

	// Flips the shape horizontally.
	function setFlipH($boolean) {
		$this->m_shape->setFlipH($boolean);
	}

	// Flips the shape vertically.
	function setFlipV($boolean) {
		$this->m_shape->setFlipV($boolean);
	}

	// Sets the height of a shape.
	function setHeight($int) {
		$this->m_shape->setHeight($int);
	}

	// Sets the name of a shape.
	function setName($string) {
		$this->m_shape->setName($string);
	}

	// Sets the number of degrees the specified shape is rotated around the z-axis.
	function setRotation($int) {
		$this->m_shape->setRotation($int);
	}

	// Sets the width of a shape.
	function setWidth($int) {
		$this->m_shape->setWidth($int);
	}

	// Sets the x-coordinate of the upper-left corner of a shape.
	function setX($int) {
		$this->m_shape->setX($int);
	}

	// Sets the y-coordinate of the upper-left corner of a shape.
	function setY($int) {
		$this->m_shape->setY($int);
	}

	// Moves the shape in front of or behind other shapes in the collection (that is, changes the shape's position in the z-order).
	function zOrder($int) {
		$this->m_shape->zOrder($int);
	}
}

// Represents the collection of a shapes.
class Shapes {

	public $m_shapes;

	function __construct($shapes) {
		$this->m_shapes = $shapes;
	}

	// Adds an AudioFrame with embedded audio file to the end of collection.
	function addAudioFrameEmbedded($intX, $intY, $intWidth, $intHeight, $input) {
		$audioFrame = null;
		if (is_string($input)) {
			$input_file = new Java('java.io.File', $input);
			$input_stream = new Java('java.io.FileInputStream', $input_file);
			$audioFrame = $this->m_shapes->addAudioFrameEmbedded($intX, $intY, $intWidth, $intHeight, $input_stream);
			$input_stream->close();
		} else {
			$audioFrame = $this->m_shapes->addAudioFrameEmbedded($intX, $intY, $intWidth, $intHeight, $input);
		}
		$audioFrame_php = new AudioFrame($audioFrame);
		return $audioFrame_php;
	}

	// Adds an AudioFrame with linked audio file to the end of collection.
	function addAudioFrameLinked($intX, $intY, $intWidth, $intHeight, $stringFname) {
		$audioFrame = $this->m_shapes->addAudioFrameLinked($intX, $intY, $intWidth, $intHeight, $stringFname);
		$audioFrame_php = new AudioFrame($audioFrame);
		return $audioFrame_php;
	}

	// Adds the Ellipse at the end of the collection.
	function addEllipse($intX, $intY, $intWidth, $intHeight) {
		$ellipse = $this->m_shapes->addEllipse($intX, $intY, $intWidth, $intHeight);
		$ellipse_php = new Ellipse($ellipse);
		return $ellipse_php;
	}

	// Adds the Line at the end of the collection.
	function addLine($pointPt1, $pointPt2) {
		$line = $this->m_shapes->addLine($pointPt1, $pointPt2);
		$line_php = new Line($line);
		return $line_php;
	}

	// Adds an OleObjectFrame to the end of collection.
	function addOleObjectFrame($intX, $intY, $intWidth, $intHeight, $stringClassName, $byteObjData) {
		$oleObjectFrame = $this->m_shapes->addOleObjectFrame($intX, $intY, $intWidth, $intHeight, $stringClassName, $byteObjData);
		$oleObjectFrame_php = new OleObjectFrame($oleObjectFrame);
		return $oleObjectFrame_php;
	}

	// Adds the PictureFrame at the end of the collection.
	function addPictureFrame($intId, $intX, $intY, $intWidth, $intHeight) {
		$pictureFrame = $this->m_shapes->addPictureFrame($intId, $intX, $intY, $intWidth, $intHeight);
		$pictureFrame_php = new PictureFrame($pictureFrame);
		return $pictureFrame_php;
	}

	// Adds the Rectangle at the end of the collection.
	function addRectangle($intX, $intY, $intWidth, $intHeight) {
		$rectangle = $this->m_shapes->addRectangle($intX, $intY, $intWidth, $intHeight);
		$rectangle_php = new Rectangle($rectangle);
		return $rectangle_php;
	}

	// Adds a Table to the end of collection.
	function addTable($intX, $intY, $intWidth, $intHeight, $intColumns, $intRows, $doubleBordersWidth = null, $colorBorders = null) {
		$table = null;
		if (doubleBordersWidth == null) {
			$table = $this->m_shapes->addTable($intX, $intY, $intWidth, $intHeight, $intColumns, $intRows);
		} else {
			$table = $this->m_shapes->addTable($intX, $intY, $intWidth, $intHeight, $intColumns, $intRows, $doubleBordersWidth, $colorBorders);
		}
		$table_php = new Table($table);
		return $table_php;
	}

	// Adds a VideoFrame to the end of collection.
	function addVideoFrame($intX, $intY, $intWidth, $intHeight, $stringFname) {
		$videoFrame = $this->m_shapes->addVideoFrame($intX, $intY, $intWidth, $intHeight, $stringFname);
		$videoFrame_php = new VideoFrame($videoFrame);
		return $videoFrame_php;
	}

	// Returns the element at the specified index.
	function get($int) {
		$shape = $this->m_shapes->get($int);
		$cf = new ClassFactory();
		$shape_php = $cf->CreateShapePhp($shape);
		return $shape_php;
	}

	// Returns parent object for the Shapes collection.
	function getParent() {
		$object = $this->m_shapes->getParent();
		$cf = new ClassFactory();
		$object_php = $cf->CreateShapesParentPhp($object);
		return $object_php;
	}

	// Returns the zero-based index of the first occurrence of a value in the ArrayList.
	function indexOf($shape_php) {
		$int = $this->m_shapes->indexOf($shape_php->m_shape);
		return $int;
	}

	// Removes the element at the specified index of the collection.
	function removeAt($int) {
		$this->m_shapes->remove($int);
	}

	// Removes the element at the specified index of the collection.
	function remove($shape_php) {
		$this->m_shapes->remove($shape_php->m_shape);
	}

	// Returns the number of elements in the collection.
	function size() {
		$int = $this->m_shapes->size();
		return $int;
	}
}

// Represents the slide in a presentation.
class Slide {

	public $m_slide;

	function __construct($slide) {
		$this->m_slide = $slide;
	}

	// Adds the empty notes to a slide.
	function addNotes() {
		$this->m_slide->addNotes();
	}

	// Replaces the master slide for a slide.
	function changeMaster($slide_php) {
		$this->m_slide->changeMaster($slide_php->m_slide);
	}

	// Search and return the shape with defined alternative text.
	function findShape($string) {
		$shape = $slide->findShape($string);
		$cf = new ClassFactory();
		$shape_php = $cf->CreateShapePhp($shape);
		return $shape_php;
	}

	// Returns the background of a slide.
	function getBackground() {
		$background = $this->m_slide->getBackground();
		$background_php = new Background($background);
		return $background_php;
	}

	// Returns the header and footer settings for a slide.
	function getHeaderFooter() {
		$headerFooter = $this->m_slide->getHeaderFooter();
		$headerFooter_php = new HeaderFooter($headerFooter);
		return $headerFooter_php;
	}

	// Returns the slide layout.
	function getLayout() {
		$int = $this->m_slide->getLayout();
		return $int;
	}

	// Returns the Id of a master slide.
	function getMasterId() {
		$long = $this->m_slide->getMasterId();
		return $long;
	}

	// Returns the name of a slide.
	function getName() {
		$string = $this->m_slide->getName();
		return $string;
	}

	// Returns the notes of a slide.
	function getNotes() {
		$notes = $this->m_slide->getNotes();
		$notes_php = new Notes($notes);
		return $notes_php;
	}

	// Returns the parent presentation.
	function getParent() {
		$presentation = $this->m_slide->getParent();
		$presentation_php = new Presentation($presentation);
		return $presentation_php;
	}

	// Returns the placeholders of a slide.
	function getPlaceholders() {
		$placeholders = $this->m_slide->getPlaceholders();
		$placeholders_php = new Placeholders($placeholders);
		return $placeholders_php;
	}

	// Returns the shapes of a slide.
	function getShapes() {
		$shapes = $this->m_slide->getShapes();
		$shapes_php = new Shapes($shapes);
		return $shapes_php;
	}

	// Returns the Id of a slide.
	function getSlideId() {
		$long = $this->m_slide->getSlideId();
		return $long;
	}

	// Returns the position of a slide.
	function getSlidePosition() {
		$int = $this->m_slide->getSlidePosition();
		return $int;
	}

	// Returns the SlideShowTransition object which contains information about how the specified slide advances during a slide show.
	function getSlideShowTransition() {
		$slideShowTransition = $this->m_slide->getSlideShowTransition();
		$slideShowTransition_php = new SlideShowTransition($slideShowTransition);
		return $slideShowTransition_php;
	}

	// Returns the tags of a slide.
	function getTags() {
		$tags = $this->m_slide->getTags();
		$tags_php = new Tags($tags);
		return $tags_php;
	}

	// Determines whether the slide follows the master slide background.
	function isFollowMasterBackground() {
		$boolean = $this->m_slide->isFollowMasterBackground();
		return $boolean;
	}

	// Determines whether the slide objects follow the master slide objects style.
	function isFollowMasterObjects() {
		$boolean = $this->m_slide->isFollowMasterObjects();
		return $boolean;
	}

	// Determines whether the slide follows the master slide color scheme.
	function isFollowMasterScheme() {
		$boolean = $this->m_slide->isFollowMasterScheme();
		return $boolean;
	}

	// Creates image of a slide in SVG (vector graphics) format and writes it to a stream.
	function saveToSVG($output) {
		if (is_string($output)) {
			$output_file = new Java('java.io.File', $output);
			$output_stream = new Java('java.io.FileOutputStream', $output_file);
			$this->m_slide->saveToSVG($output_stream);
			$output_stream->flush();
			$output_stream->close();
		} else {
			$this->m_slide->saveToSVG($output);
		}
	}

	// Sets whether the slide follows the master slide background.
	function setFollowMasterBackground($boolean) {
		$this->m_slide->setFollowMasterBackground($boolean);
	}

	// Sets whether the slide objects follow the master slide objects style.
	function setFollowMasterObjects($boolean) {
		$this->m_slide->setFollowMasterObjects($boolean);
	}

	// Sets whether the slide follows the master slide color scheme.
	function setFollowMasterScheme($boolean) {
		$this->m_slide->setFollowMasterScheme($boolean);
	}

	// Sets the slide layout.
	function setLayout($int) {
		$this->m_slide->setLayout($int);
	}

	// Sets the ID of a master slide.
	function setMasterId($long) {
		$this->m_slide->setMasterId($long);
	}

	// Sets the name of a slide.
	function setName($string) {
		$this->m_slide->setName($string);
	}

	// Sets the position of a slide.
	function setSlidePosition($int) {
		$this->m_slide->setSlidePosition($int);
	}
}

// Represents the collection of a slides.
class Slides {

	public $m_slides;

	function __construct($slides) {
		$this->m_slides = $slides;
	}

	// Returns the element at the specified index.
	function get($index) {
		$slide = $this->m_slides->get($index);
		$cf = new ClassFactory();
		$slide_php = $cf->CreateSlidePhp($slide);
		return $slide_php;
	}

	// Returns the position of the last slide in a presentation.
	function getLastSlidePosition() {
		$index = $this->m_slides->getLastSlidePosition();
		return $index;
	}

	// Removes the first occurrence of a specific object from the collection.
	function remove($slide) {
		$this->m_slides->remove($slide->m_slide);
	}

	// Removes the element at the specified index of the collection.
	function removeAt($index) {
		$this->m_slides->removeAt($index);
	}

	// Returns the number of elements in the collection.
	function size() {
		$size = $this->m_slides->size();
		return $size;
	}
}

// Represents default settings for a presentation's slide show.
class SlideShowSettings {

	public $m_slideShowSettings;

	function __construct($slideShowSettings) {
		$this->m_slideShowSettings = $slideShowSettings;
	}

	// Returns the last slide to be displayed in the slide show.
	function getEndingSlide() {
		$short = $this->m_slideShowSettings->getEndingSlide();
		return $short;
	}

	// Returns the color of a pointer for a presentation.
	function getPointerColor() {
		$color = $this->m_slideShowSettings->getPointerColor();
		return $color;
	}

	// Returns the slide show range type.
	function getRangeType() {
		$int = $this->m_slideShowSettings->getRangeType();
		return $int;
	}

	// Returns the slide show type.
	function getShowType() {
		$int = $this->m_slideShowSettings->getShowType();
		return $int;
	}

	// Returns the first slide to be displayed in the slide show.
	function getStartingSlide() {
		$short = $this->m_slideShowSettings->getStartingSlide();
		return $short;
	}

	// Determines whether the slide show loops continuously until the user presses ESC.
	function isLoopUntilStopped() {
		$boolean = $this->m_slideShowSettings->isLoopUntilStopped();
		return $boolean;
	}

	// Determines whether the slide show advances manually.
	function isManualAdvance() {
		$boolean = $this->m_slideShowSettings->isManualAdvance();
		return $boolean;
	}

	// Determines whether the scrollbar visible during a slide show in browse mode.
	function isShowScrollbar() {
		$boolean = $this->m_slideShowSettings->isShowScrollbar();
		return $boolean;
	}

	// Determines whether the slide show displays shapes with animation.
	function isShowWithAnimation() {
		$boolean = $this->m_slideShowSettings->isShowWithAnimation();
		return $boolean;
	}

	// Determines whether the slide show is shown with narration.
	function isShowWithNarration() {
		$boolean = $this->m_slideShowSettings->isShowWithNarration();
		return $boolean;
	}

	// Sets the last slide to be displayed in the slide show.
	function setEndingSlide($short) {
		$this->m_slideShowSettings->setEndingSlide($short);
	}

	// Sets whether the slide show loops continuously until the user presses ESC.
	function setLoopUntilStopped($boolean) {
		$this->m_slideShowSettings->setLoopUntilStopped($boolean);
	}

	// Sets whether the slide show advances manually.
	function setManualAdvance($boolean) {
		$this->m_slideShowSettings->setManualAdvance($boolean);
	}

	// Sets the color of a pointer for a presentation.
	function setPointerColor($color) {
		$this->m_slideShowSettings->setPointerColor($color);
	}

	// Sets the slide show range type.
	function setRangeType($int) {
		$this->m_slideShowSettings->setRangeType($int);
	}

	// Sets whether the scrollbar visible during a slide show in browse mode.
	function setShowScrollbar($boolean) {
		$this->m_slideShowSettings->setShowScrollbar($boolean);
	}

	// Sets the slide show type.
	function setShowType($int) {
		$this->m_slideShowSettings->setShowType($int);
	}

	// Sets whether the slide show displays shapes with animation.
	function setShowWithAnimation($boolean) {
		$this->m_slideShowSettings->setShowWithAnimation($boolean);
	}

	// Sets whether the slide show is shown with narration.
	function setShowWithNarration($boolean) {
		$this->m_slideShowSettings->setShowWithNarration($boolean);
	}

	// Sets the first slide to be displayed in the slide show.
	function setStartingSlide($short) {
		$this->m_slideShowSettings->setStartingSlide($short);
	}
}

// Represents information about how the specified slide advances during a slide show.
class SlideShowTransition {

	public $m_slideShowTransition;

	function __construct($slideShowTransition) {
		$this->m_slideShowTransition = $slideShowTransition;
	}

	// Returns the amount of time, in seconds, after which the specified slide transition will occur.
	function getAdvanceTime() {
		$double = $this->m_slideShowTransition->getAdvanceTime();
		return $double;
	}

	// Returns the special effect applied to the specified slide transition.
	function getEntryEffect() {
		$int = $this->m_slideShowTransition->getEntryEffect();
		return $int;
	}

	// Determines whether the specified slide has sound during a slide show.
	function getSound() {
		$oolean = $this->m_slideShowTransition->getSound();
		return $oolean;
	}

	// Returns the speed of a slide transition.
	function getSpeed() {
		$int = $this->m_slideShowTransition->getSpeed();
		return $int;
	}

	// Determines whether the specified slide advances when it's clicked during a slide show.
	function isAdvanceOnClick() {
		$boolean = $this->m_slideShowTransition->isAdvanceOnClick();
		return $boolean;
	}

	// Determines whether the specified slide advances automatically after a specified amount of time has elapsed.
	function isAdvanceOnTime() {
		$boolean = $this->m_slideShowTransition->isAdvanceOnTime();
		return $boolean;
	}

	// Determines whether the specified slide is hidden during a slide show.
	function isHidden() {
		$boolean = $this->m_slideShowTransition->isHidden();
		return $boolean;
	}

	// Determines whether the sound that's been set for the specified slide transition loops until the next sound starts.
	function isLoopSoundUntilNext() {
		$boolean = $this->m_slideShowTransition->isLoopSoundUntilNext();
		return $boolean;
	}

	// Sets whether the specified slide advances when it's clicked during a slide show.
	function setAdvanceOnClick($boolean) {
		$this->m_slideShowTransition->setAdvanceOnClick($boolean);
	}

	// Sets whether the specified slide advances automatically after a specified amount of time has elapsed.
	function setAdvanceOnTime($boolean) {
		$this->m_slideShowTransition->setAdvanceOnTime($boolean);
	}

	// Sets the amount of time, in seconds, after which the specified slide transition will occur.
	function setAdvanceTime($double) {
		$this->m_slideShowTransition->setAdvanceTime($double);
	}

	// Sets the special effect applied to the specified slide transition.
	function setEntryEffect($int) {
		$this->m_slideShowTransition->setEntryEffect($int);
	}

	// Sets whether the specified slide is hidden during a slide show.
	function setHidden($boolean) {
		$this->m_slideShowTransition->setHidden($boolean);
	}

	// Sets whether the sound that's been set for the specified slide transition loops until the next sound starts.
	function setLoopSoundUntilNext($boolean) {
		$this->m_slideShowTransition->setLoopSoundUntilNext($boolean);
	}

	// Sets the speed of a slide transition.
	function setSpeed($int) {
		$this->m_slideShowTransition->setSpeed($int);
	}
}

// Represents the tabulation for a text.
class Tab {

	public $m_tab;

	function __construct($tab) {
		$this->m_tab = $tab;
	}

	// Returns the align style of a tab.
	function getAlign() {
		$int = $this->m_tab->getAlign();
		return $int;
	}

	// Returns the position of a tab.
	function getPosition() {
		$int = $this->m_tab->getPosition();
		return $int;
	}

	// Sets the align style of a tab.
	function setAlign($int) {
		$this->m_tab->setAlign($int);
	}

	// Sets the position of a tab.
	function setPosition($int) {
		$this->m_tab->setPosition($int);
	}
}

// Represents the table on a slide.
class Table extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns the collection of shapes inside the group.
	function getShapes() {
		$shapes = $this->m_shape->getShapes();
		$shapes_php = new Shapes($shapes);
		return $shapes_php;
	}

	// Clones last column of a table and adds new column at the end of the table.
	function addColumn() {
		$this->m_shape->addColumn();
	}

	// Clones last row of a table and adds new row at the end of the table.
	function addRow() {
		$this->m_shape->addRow();
	}

	// Deletes column from a table.
	function deleteColumn($int) {
		$this->m_shape->deleteColumn($int);
	}

	// Deletes row from a table.
	function deleteRow($int) {
		$this->m_shape->deleteRow($int);
	}

	// Returns the cell of a table.
	function getCell($intColumn, $intRow) {
		$cell = $this->m_shape->getCell($intColumn, $intRow);
		$cell_php = new Cell($cell);
		return $cell_php;
	}

	// Returns number of columns in the table.
	function getColumnsNumber() {
		$int = $this->m_shape->getColumnsNumber();
		return $int;
	}

	// Returns the width of the specified column in a table.
	function getColumnWidth($int) {
		$int = $this->m_shape->getColumnWidth($int);
		return $int;
	}

	// Returns user set row height.
	function getMinimalRowHeight($int) {
		$int = $this->m_shape->getMinimalRowHeight($int);
		return $int;
	}

	// Returns the height of the specified row in a table.
	function getRowHeight($int) {
		$int = $this->m_shape->getRowHeight($int);
		return $int;
	}

	// Returns number of rows in the table.
	function getRowsNumber() {
		$int = $this->m_shape->getRowsNumber();
		return $int;
	}

	// Merges two cells or throws exception if cells can't be merged.
	function mergeCells($cellCell1_php, $cellCell2_php) {
		$cell = $this->m_shape->mergeCells($cellCell1_php->m_cell, $cellCell2_php->m_cell);
		$cell_php = new Cell($cell);
		return $cell_php;
	}

	function setBorders($double, $color) {
		$this->m_shape->setBorders($double, $color);
	} 

	// Sets new width for the specified column in a table.
	function setColumnWidth($intColumn, $intWidth) {
		$this->m_shape->setColumnWidth($intColumn, $intWidth);
	}

	// Sets new height for the specified row in a table.
	function setRowHeight($intRow, $intHeight) {
		$this->m_shape->setRowHeight($intRow, $intHeight);
	}

	// Splits cell of a table horizontally on two parts.
	function splitCellH($cell_php) {
		$this->m_shape->splitCellH($cell_php->m_cell);
	}

	// Splits cell of a table vertically on two parts.
	function splitCellV($cell_php) {
		$this->m_shape->splitCellV($cell_php->m_cell);
	}
}

// Represents the collection of a tabulations.
class Tabs {

	public $m_tabs;

	function __construct($tabs) {
		$this->m_tabs = $tabs;
	}

	// Adds the tab at the end of a collection.
	function add($tab_php) {
		$int = $this->m_tabs->add($tab_php->m_tab);
		return $int;
	}

	// Removes all tabs from a collection.
	function clear() {
		$this->m_tabs->clear();
	}

	// Returns the element at the specified index.
	function get($int) {
		$tab = $this->m_tabs->get($int);
		$tab_php = new Tab($tab);
		return $tab_php;
	}

	// Removes the tab at the specified index of a collection.
	function remove($int) {
		$this->m_tabs->remove($int);
	}

	// Returns the number of the elements in a collection.
	function size() {
		$int = $this->m_tabs->size();
		return $int;
	}
}

// Represents the collection of a tags.
class Tags {

	public $m_tags;

	function __construct($tags) {
		$this->m_tags = $tags;
	}

	// Removes all tags.
	function clear() {
		$this->m_tags->clear();
	}

	// Determines whether the collection contains a tag with the specific name.
	function containsTag($string) {
		$boolean = $this->m_tags->containsTag($string);
		return $boolean;
	}

	// Returns the tag associated with the specific name.
	function get($name) {
		$string = $this->m_tags->get($name);
		return $string;
	}

	// Gets the tag name at the specified index of the collection.
	function getTagName($int) {
		$string = $this->m_tags->getTagName($int);
		return $string;
	}

	// Adds the tag with the specified name.
	function put($stringName, $string) {
		$this->m_tags->put($stringName, $string);
	}

	// Removes the tag with the specified name from collection.
	function remove($stringName) {
		$this->m_tags->remove($stringName);
	}

	// Sets the tag associated with the specific name.
	function set($stringName, $string) {
		$this->m_tags->set($stringName, $string);
	}

	// Returns the number of a tags in a collection.
	function size() {
		$int = $this->m_tags->size();
		return $int;
	}
}

// Represents the TextFrame shape.
class TextFrame extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Decreases Paragraph's SpaceWithin and/or FontHeight
	// to fit text to a TextFrame's rectangle.
	function fitTextToShape() {
		$this->m_shape->fitTextToShape();
	}

	// Returns the anchor text in a TextFrame.
	function getAnchorText() {
		$int = $this->m_shape->getAnchorText();
		return $int;
	}

	// Returns the position of a DateTime meta character in a TextFrame.
	// -1 if a TextFrame doesn't contain DateTime meta character.
	function getDateTimePosition() {
		$int = $this->m_shape->getDateTimePosition();
		return $int;
	}

	// Returns the list of tabulations for a paragraph,
	// including implicitly generated.
	function getEffectiveTabs($intParagraphNumber) {
		$effectiveTabs = $this->m_shape->getEffectiveTabs($intParagraphNumber);
		$effectiveTabs_php = new EffectiveTabs($effectiveTabs);
		return $effectiveTabs_php;
	}

	// Returns additional rotation of text in a shape.
	function getFontRotation() {
		$int = $this->m_shape->getFontRotation();
		return $int;
	}

	// Returns the position of a Footer meta character in a TextFrame.
	// -1 if a TextFrame doesn't contain Footer meta character.
	function getFooterPosition() {
		$int = $this->m_shape->getFooterPosition();
		return $int;
	}

	// Returns the position of a GenericDate meta character in a TextFrame.
	// -1 if a TextFrame doesn't contain GenericDate meta character.
	function getGenericDatePosition() {
		$int = $this->m_shape->getGenericDatePosition();
		return $int;
	}

	// Returns the position of a Header meta character in a TextFrame.
	// -1 if a TextFrame doesn't contain Header meta character.
	function getHeaderPosition() {
		$int = $this->m_shape->getHeaderPosition();
		return $int;
	}

	// Returns the list of all links in a frame.
	function getLinks() {
		$links = $this->m_shape->getLinks();
		$links_php = new Links($links);
		return $links_php;
	}

	// Returns the bottom margin (mm) in a TextFrame.
	function getMarginBottom() {
		$double = $this->m_shape->getMarginBottom();
		return $double;
	}

	// Returns the left margin (mm) in a TextFrame.
	function getMarginLeft() {
		$double = $this->m_shape->getMarginLeft();
		return $double;
	}

	// Returns the right margin (mm) in a TextFrame.
	function getMarginRight() {
		$double = $this->m_shape->getMarginRight();
		return $double;
	}

	// Returns the top margin (mm) in a TextFrame.
	function getMarginTop() {
		$double = $this->m_shape->getMarginTop();
		return $double;
	}

	// Returns the list of all paragraphs in a frame.
	function getParagraphs() {
		$paragraphs = $this->m_shape->getParagraphs();
		$paragraphs_php = new Paragraphs($paragraphs);
		return $paragraphs_php;
	}

	// Returns the position of a SlideNumber meta character in a TextFrame. -1 if a TextFrame doesn't contain SlideNumber meta character.
	function getSlideNumberPosition() {
		$int = $this->m_shape->getSlideNumberPosition();
		return $int;
	}

	// Returns the list of all tabulation defined for a frame or null if tabulations were not defined for this frame.
	function getTabs() {
		$tabs = $this->m_shape->getTabs();
		$tabs_php = new Tabs($tabs);
		return $tabs_php;
	}

	// Returns the plain text for a TextFrame.
	function getText() {
		$string = $this->m_shape->getText();
		return $string;
	}

	// Returns a TextRuler of a textframe.
	function getTextRuler() {
		$textRuler = $this->m_shape->getTextRuler();
		$textRuler_php = new TextRuler($textRuler);
		return $textRuler_php;
	}

	// Determines whether the TextFrame size fitted to the text.
	function isFitShapeToText() {
		$boolean = $this->m_shape->isFitShapeToText();
		return $boolean;
	}

	// Determines whether the text of TextFrame is rotated by 90 degree.
	function isRotateTextBy90Degrees() {
		$boolean = $this->m_shape->isRotateTextBy90Degrees();
		return $boolean;
	}

	// Determines whether the text is wrapped at TextFrame's margins.
	function isWrapText() {
		$boolean = $this->m_shape->isWrapText();
		return $boolean;
	}

	// Sets the anchor text in a TextFrame.
	function setAnchorText($int) {
		$this->m_shape->setAnchorText($int);
	}

	// Sets whether the TextFrame size fitted to the text.
	function setFitShapeToText($boolean) {
		$this->m_shape->setFitShapeToText($boolean);
	}

	// Sets additional rotation of text in a shape.
	function setFontRotation($int) {
		$this->m_shape->setFontRotation($int);
	}

	// Sets the bottom margin (mm) in a TextFrame.
	function setMarginBottom($double) {
		$this->m_shape->setMarginBottom($double);
	}

	// Sets the left margin (mm) in a TextFrame.
	function setMarginLeft($double) {
		$this->m_shape->setMarginLeft($double);
	}

	// Sets the right margin (mm) in a TextFrame.
	function setMarginRight($double) {
		$this->m_shape->setMarginRight($double);
	}

	// Sets the top margin (mm) in a TextFrame.
	function setMarginTop($double) {
		$this->m_shape->setMarginTop($double);
	}

	// Sets whether the text of TextFrame is rotated by 90 degree.
	function setRotateTextBy90Degrees($boolean) {
		$this->m_shape->setRotateTextBy90Degrees($boolean);
	}

	// Sets the plain text for a TextFrame.
	function setText($string) {
		$this->m_shape->setText($string);
	}

	// Sets whether the text is wrapped at TextFrame's margins.
	function setWrapText($boolean) {
		$this->m_shape->setWrapText($boolean);
	}
}

// Represents the text placeholder.
class TextHolder extends Placeholder {

	function __construct($textHolder) {
		parent::__construct($textHolder);
	}

	// Decreases Paragraph's SpaceWithin and/or FontHeight
	// to fit text to a TextHolder's rectangle.
	function fitTextToShape() {
		$this->m_placeholder->fitTextToShape();
	}

	// Returns the alternative text associated with a textholder in a Web presentation.
	function getAlternativeText() {
		$string = $this->m_placeholder->getAlternativeText();
		return $string;
	}

	// Returns the anchor text in a TextHolder.
	function getAnchorText() {
		$int = $this->m_placeholder->getAnchorText();
		return $int;
	}

	// Returns a list of tabulations for a paragraph, including implicitly generated.
	function getEffectiveTabs($int) {
		$effectiveTabs = $this->m_placeholder->getEffectiveTabs($int);
		$effectiveTabs_php = new FillFormat($effectiveTabs);
		return $effectiveTabs_php;
	}

	// Returns the FillFormat object that contains fill formatting properties for a TextHolder.
	function getFillFormat() {
		$fillFormat = $this->m_placeholder->getFillFormat();
		$fillFormat_php = new FillFormat($fillFormat);
		return $fillFormat_php;
	}

	// Returns the height of a frame.
	function getHeight() {
		$int = $this->m_placeholder->getHeight();
		return $int;
	}

	// Returns the LineFormat object that contains line formatting properties for a TextHolder.
	function getLineFormat() {
		$lineFormat = $this->m_placeholder->getLineFormat();
		$lineFormat_php = new LineFormat($lineFormat);
		return $lineFormat_php;
	}

	// Returns the list of all links in a frame.
	function getLinks() {
		$links = $this->m_placeholder->getLinks();
		$links_php = new Links($links);
		return $links_php;
	}

	// Returns the bottom margin (mm) in a TextHolder.
	function getMarginBottom() {
		$double = $this->m_placeholder->getMarginBottom();
		return $double;
	}

	// Returns the left margin (mm) in a TextHolder.
	function getMarginLeft() {
		$double = $this->m_placeholder->getMarginLeft();
		return $double;
	}

	// Returns the right margin (mm) in a TextHolder.
	function getMarginRight() {
		$double = $this->m_placeholder->getMarginRight();
		return $double;
	}

	// Returns the top margin (mm) in a TextHolder.
	function getMarginTop() {
		$double = $this->m_placeholder->getMarginTop();
		return $double;
	}

	// Returns the list of all paragraphs in a frame.
	function getParagraphs() {
		$paragraphs = $this->m_placeholder->getParagraphs();
		$paragraphs_php = new Paragraphs($paragraphs);
		return $paragraphs_php;
	}

	// Returns the Shape object which contains real properties of a TextHolder.
	function getShapeRef() {
		$shape = $this->m_placeholder->getShapeRef();
		$cf = new ClassFactory();
		$shape_php = $cf->CreateShapePhp($shape);
		return $shape_php;
	}

	// Returns the plain text for a TextHolder.
	function getText() {
		$string = $this->m_placeholder->getText();
		return $string;
	}

	// Returns the TextRuler of a textholder.
	function getTextRuler() {
		$textRuler = $this->m_placeholder->getTextRuler();
		$textRuler_php = new Shape($textRuler);
		return $textRuler_php;
	}

	// Returns the width of a frame.
	function getWidth() {
		$int = $this->m_placeholder->getWidth();
		return $int;
	}

	// Returns the x-coordinate of the upper-left corner of a frame.
	function getX() {
		$int = $this->m_placeholder->getX();
		return $int;
	}

	// Returns the y-coordinate of the upper-left corner of a frame.
	function getY() {
		$int = $this->m_placeholder->getY();
		return $int;
	}

	// Determines whether the TextHolder size fitted to the text.
	function isFitShapeToText() {
		$boolean = $this->m_placeholder->isFitShapeToText();
		return $boolean;
	}

	// True to rotate text of TextHolder by 90 degree.
	function isRotateTextBy90Degrees() {
		$boolean = $this->m_placeholder->isRotateTextBy90Degrees();
		return $boolean;
	}

	// Determines whether the text is wrapped at TextHolder's margins.
	function isWrapText() {
		$boolean = $this->m_placeholder->isWrapText();
		return $boolean;
	}

	// Sets the alternative text associated with a textholder in a Web presentation.
	function setAlternativeText($string) {
		$this->m_placeholder->setAlternativeText($string);
	}

	// Sets the anchor text in a TextHolder.
	function setAnchorText($int) {
		$this->m_placeholder->setAnchorText($int);
	}

	// Sets whether the TextHolder size fitted to the text.
	function setFitShapeToText($boolean) {
		$this->m_placeholder->setFitShapeToText($boolean);
	}

	// Sets the height of a frame.
	function setHeight($int) {
		$this->m_placeholder->setHeight($int);
	}

	// Sets the bottom margin (mm) in a TextHolder.
	function setMarginBottom($double) {
		$this->m_placeholder->setMarginBottom($double);
	}

	// Sets the left margin (mm) in a TextHolder.
	function setMarginLeft($double) {
		$this->m_placeholder->setMarginLeft($double);
	}

	// Sets the right margin (mm) in a TextHolder.
	function setMarginRight($double) {
		$this->m_placeholder->setMarginRight($double);
	}

	// Sets the top margin (mm) in a TextHolder.
	function setMarginTop($double) {
		$this->m_placeholder->setMarginTop($double);
	}

	function setRotateTextBy90Degrees($boolean) {
		$this->m_placeholder->setRotateTextBy90Degrees($boolean);
	}

	// Sets the plain text for a TextHolder.
	function setText($string) {
		$this->m_placeholder->setText($string);
	}

	// Sets the width of a frame.
	function setWidth($int) {
		$this->m_placeholder->setWidth($int);
	}

	// Sets whether the text is wrapped at TextHolder's margins.
	function setWrapText($boolean) {
		$this->m_placeholder->setWrapText($boolean);
	}

	// Sets the x-coordinate of the upper-left corner of a frame.
	function setX($int) {
		$this->m_placeholder->setX($int);
	}

	// Sets the y-coordinate of the upper-left corner of a frame.
	function setY($int) {
		$this->m_placeholder->setY($int);
	}
}

class TextRuler {

	public $m_textRuler;

	function __construct($textRuler) {
		$this->m_textRuler = $textRuler;
	}

	// Returns the distance between two implicit tabulations.
	function getDefaultTabInterval() {
		$short = $this->m_textRuler->getDefaultTabInterval();
		return $short;
	}

	// Returns a collection of paragraph level information.
	function getLevels() {
		$textLevels = $this->m_textRuler->getLevels();
		return $textLevels;
	}

	// Returns the list of tabulation defined for a ruler.
	function getTabs() {
		$tabs = $this->m_textRuler->getTabs();
		$tabs_php = new Tabs($tabs);
		return $tabs_php;
	}

	// Sets the distance between two implicit tabulations.
	function setDefaultTabInterval($short) {
		$this->m_textRuler->setDefaultTabInterval($short);
	}
}

// Represents a VideoFrame shape.
class VideoFrame extends Shape {

	function __construct($shape) {
		parent::__construct($shape);
	}

	// Returns the file from which the media object was created.
	function getFileName() {
		$string = $this->m_shape->getFileName();
		return $string;
	}

	// Determines whether the movie loops continuously until either the next movie or sound starts, the user clicks the slide, or a slide transition occurs.
	function isLoopUntilStopped() {
		$boolean = $this->m_shape->isLoopUntilStopped();
		return $boolean;
	}

	// Determines whether the movie is automatically rewinded to start as soon as the movie has finished playing.
	function isRewindMovie() {
		$boolean = $this->m_shape->isRewindMovie();
		return $boolean;
	}

	// Sets the file from which the media object was created.
	function setFileName($string) {
		$this->m_shape->setFileName($string);
	}

	// Sets whether the movie loops continuously until either the next movie or sound starts, the user clicks the slide, or a slide transition occurs.
	function setLoopUntilStopped($boolean) {
		$this->m_shape->setLoopUntilStopped($boolean);
	}

	// Sets whether the movie is automatically rewinded to start as soon as the movie has finished playing.
	function setRewindMovie($boolean) {
		$this->m_shape->setRewindMovie($boolean);
	}

	// Returns the brightness (0-100%) of a picture.
	function getBrightness() {
		$int = $this->m_shape->getBrightness();
		return $int;
	}

	// Returns the type of color transformation applied to a picture.
	function getColorType() {
		$int = $this->m_shape->getColorType();
		return $int;
	}

	// Returns the contrast (0-100%) of a picture.
	function getContrast() {
		$int = $this->m_shape->getContrast();
		return $int;
	}

	// Returns the number of percents of real image height that are cropped off the bottom of the picture.
	function getCropBottom() {
		$double = $this->m_shape->getCropBottom();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the left of the picture.
	function getCropLeft() {
		$double = $this->m_shape->getCropLeft();
		return $double;
	}

	// Returns the number of percents of real image width that are cropped off the right of the picture.
	function getCropRight() {
		$double = $this->m_shape->getCropRight();
		return $double;
	}

	// Returns the number of percents of real image height that are cropped off the top of the picture.
	function getCropTop() {
		$double = $this->m_shape->getCropTop();
		return $double;
	}

	// Returns the picture Id for a PictureFrame.
	function getPictureId() {
		$int = $this->m_shape->getPictureId();
		return $int;
	}

	// Returns the table of colors replacements for recoloring metafiles.
	function getRecolor() {
		$recolorTable = $this->m_shape->getRecolor();
		$recolorTable_php = new RecolorTable($recolorTable);
		return $recolorTable_php;
	}

	// Returns the transparent color of a picture.
	// java.awt.Color
	function getTransparentColor() {
		$color = $this->m_shape->getTransparentColor();
		return $color;
	}

	// Sets the brightness (0-100%) of a picture.
	function setBrightness($int) {
		$this->m_shape->setBrightness($int);
	}

	// Sets the type of color transformation applied to a picture.
	function setColorType($int) {
		$this->m_shape->setColorType($int);
	}

	// Sets the contrast (0-100%) of a picture.
	function setContrast($int) {
		$this->m_shape->setContrast($int);
	}

	// Sets the number of percents of real image height that are cropped off the bottom of the picture.
	function setCropBottom($double) {
		$this->m_shape->setCropBottom($double);
	}

	// Sets the number of percents of real image width that are cropped off the left of the picture.
	function setCropLeft($double) {
		$this->m_shape->setCropLeft($double);
	}

	// Sets the number of percents of real image width that are cropped off the right of the picture.
	function setCropRight($double) {
		$this->m_shape->setCropRight($double);
	}

	// Sets the number of percents of real image height that are cropped off the top of the picture.
	function setCropTop($double) {
		$this->m_shape->setCropTop($double);
	}

	// Sets the picture Id for a PictureFrame.
	function setPictureId($int) {
		$this->m_shape->setPictureId($int);
	}

	// sets the transparent color of a picture.
	function setTransparentColor($Color) {
		$this->m_shape->setTransparentColor($Color);
	}
}
?>
